-- 1st scenario in campaign
-- Players:
	-- 0 [H]:	Condor Legion, Spain (Nationalist)
	-- 1 [AI]:	Spanish Republic
p_SR=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Control 2 victory hexes	Cadiz (7;24) and Seville Airfield (10;14)
	-- 1 opt	Hold victory hexes		Auxiliary Airfield (9;8)
	-- 2 opt	Custom objective		CustomSuccess2() | CustomFail2()

-- 7 Triggers defined in scenario:
	-- 1x	StartGame(NewRoundAction)			{if AlwaysTrue()}				-> OnStartGame()
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	Objective1(ObjectiveStatusAction)	{if Objective1Condition()}		-> OnObjective1()
	-- 1x	StartTurn4Message(StartTurnAction)	{if Turn4MessageCondition()}	-> Turn4MessageEffect()
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}
	-- 		CaptureAF(CaptureFlagAction)										-> OnCaptureAF()
	-- 		Village(CaptureFlagAction)											-> OnCaptureVillage()

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

VHs = {{7,24},{10,14}}	-- Cadiz and Seville Airfield, per scenario

cache = {
	loc = {{27,25}},	-- Rock of Gibraltar, per scenario
	eqs = {{"203mmM1931",19}}
}


trigger_zone = {{9,10},{8,11},{9,11},{10,11},{10,12}}	-- 5 hexes of Seville, per scenario custom objective

naval_patrol = {{4,29},{8,31}}	-- Unit ID #77 (BB Jaime I) patrol points, per scenario
naval_unit_ids = {77,78,79,80,81}	-- BB Jaime I + 2 CL + 2 DD

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{17,2},{18,2},{17,3},{18,3},{26,8},{25,9},{26,10},{26,11}}	-- N. of Carmona
}

--------------
-- Triggers --
--------------

------------------------
-- Messages to player --
------------------------

-- ** Condition for StartGame() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** 1x Effect(NewRoundAction) {if AlwaysTrue()} **
function OnStartGame()
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Seville","current_cp_format","In this campaign, you can earn Commendation Points by completing bonus objectives. Opportunities to exchange Commendation Points for various rewards will be offered as the campaign progresses.  You begin this campaign with %d Commendation Points.")), campaign.comm_points))
end

-- Updated condition from turn 4 to actually counting naval units at patrol location(s)
-- ** Condition for Turn4MessageEffect() **
function Turn4MessageCondition()
	-- if any naval unit is at either patrol point
	for _,i in pairs(naval_unit_ids) do
		if (lib.IsItemInTable(naval_patrol, world:GetUnit(i).position)) then return true end
	end
	return false
end

-- ** 1x Effect(StartTurnAction) {if Turn4MessageCondition() **
function Turn4MessageEffect()
	TutorialMessage(NSLOCTEXT("scenario_Seville","string_1","<bi>Oberleutnant Wagner: </>Mein General, the Jaime I and her escorts have arrived off the coast.  We must transport the Army of Africa by air with Ju-52s from now on."))
end

----------------
-- Objectives --
----------------

---------------------------------------------
-- Objective 0: Cadiz and Seville airfield --
---------------------------------------------

vhs_captured = 0	-- number of Victory Hexes captured
af_message_shown = false

-- ** Effect(CaptureFlagAction) **
function OnCaptureAF(action)
	if (world:GetPlayer(action.new_owner).side_id == 0 and lib.IsItemInTable(VHs, action.flag)) then	-- @FIXME: triggers for either victory hex: Cadiz / Seville airfield
		vhs_captured = vhs_captured + 1	-- @FIXME: assume this is not a re-capture
		if (vhs_captured > 1 and not af_message_shown) then	-- @FIXME: assume Cadiz captured before Seville airfield
			af_message_shown = true

			local comm = vhs_captured
			campaign.comm_points = lib.UpdateCommendationPoints(comm)
			TutorialMessage(NSLOCTEXT("scenario_Seville","string_2","<bi>Oberleutnant Wagner: </>Seville Airfield secured.  Be sure to protect it from counterattack."))
		end
	end
end

------------------------------------------
-- Objective 1: Hold Auxiliary Airfield --
------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)	-- ObjectiveStatusAction
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Seville","earned_cp_formatobj1","Bonus Objective to hold Auxiliary Airfield completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

------------------------------------------------------------------------
-- Objective 2: Garrison Five Seville Hexes with Army of Africa Units --
------------------------------------------------------------------------

message_shown = false

-- ** Condition for Objective 2 success **
-- @FIXME: called for _every_ Action
function CustomSuccess2(action)
	if (lib.CountUnitsEntered(Infantry, trigger_zone) >= 5) then
		if (not message_shown) then
			message_shown = true

			local comm = 2
			campaign.comm_points = lib.UpdateCommendationPoints(comm)
			MessageBox(string.format(tostring(NSLOCTEXT("scenario_Seville","earned_cp_format","Bonus Objective to garrison Seville completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
		end
		return true
	else
		return false
	end
end

-- ** Condition for Objective 2 failure **
-- @FIXME: called for _every_ Action
function CustomFail2(action)
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountUnitsEntered(Infantry,trigger_zone) < 5
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureVillage(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage( NSLOCTEXT("scenario_Seville","string_3","<bi>Oberleutnant Wagner: </>Mein General, some of our Spanish friends seem to have gotten lost and taken a detour to Gibraltar.  We'll have to retrieve them and a cargo ship they commandeered after the Jaime I leaves the area.") )
	end
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=60, traits={UnitTrait.OverwhelmingAttack}}	-- tank SE of Seville airfield (unnamed), per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {10,16}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SR37mmBofors","HorseTransport",0,900},{"70mmSchneiderM08","HorseTransport",0,900},{"70mmSchneiderM08","HorseTransport",0,900},{"SR20mmVKPLvz36AA","HorseTransport",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"UNL35","",0,900}}
}

-----------------------
-- Spawn enemy units --
-----------------------

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, zones[math.random(#zones)], waves[math.random(#waves)])
end
