-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 2 victory hexes	(2;10)(13;11)(14;13)(13;15)(8;16)
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Destroy units			unit ID #0 (BB Jaime I)

-- 7 Triggers defined in scenario:
	-- 1x	EnemyHero()
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 1x	Italy(StartTurnAction)				{if CheckTurn()}			-> ItalyMsg()
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)
	-- 		AntequerraAirfield(CaptureFlagAction)							-> OnCaptureAF()

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

VHs = {{2,10},{13,11},{14,13},{13,15},{8,16}}	-- 5 victory hexes, per scenario

cache = {
	loc = {{20,4}},		-- village NNE of Archidona, per scenario
	eqs = {{"203mmM1931",11},{"122mm M10-30",15}}
}

bombers = {
	loc  = {{13,15}},	-- Antequera airfield, per scenario
	units= {{"Ju52Bomber","",0,0},{"Ju52Bomber","",0,0},{"Ju52Bomber","",0,0}},
	zone = {{13,14},{14,14},{12,15},{13,15},{14,15},{13,16},{14,16}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{25,8},{26,8},{25,9},{26,9},{26,13},{27,13},{27,14},{28,14}}	-- E
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=57, traits={UnitTrait.Provocator}}	-- rcn NE of Antequera, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

------------------------
-- Messages to player --
------------------------

-- ** Condition for ItalyMsg() **
function CheckTurn()
	return world.round == 0
end

-- ** Effect(StartTurnAction) {if CheckTurn()} **
function ItalyMsg(action)
	local player = world:GetPlayer(0)
	MessageBox(NSLOCTEXT("scenario_Antequera","string_1","Italian Auxiliaries"), NSLOCTEXT("scenario_Antequera","string_2","Our Italian colleagues have committed the Corpo Truppe Volontarie to participate this Spanish conflict.  You can purchase and deploy them as temporary auxiliary units to any battle."))
end

------------------------------------------------------------
-- Objective 0: Control Two Victory Hexes at scenario end --
------------------------------------------------------------

-- ** Condition for Objective 0 success **
-- ?? checked at scenario end ??
function Player1CustomSuccess(action)
MessageBox("Player1CustomSuccess")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and Player1VH() >= 2
end

-- ** Condition for Objective 0 failure **
-- ?? checked at scenario end ??
function Player1CustomFail(action)
MessageBox("Player1CustomSuccess")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) < 2
end

--------------------------------------------------------
-- Objective 1: BONUS for capturing all victory hexes --
--------------------------------------------------------

-- ** Condition for OnObjective1() ** (Destroy unit ID #0)
-- Objective 1: BONUS Capture all victory hexes
function Objective1Condition(action)	-- ObjectiveStatusAction
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
-- Objective 1: BONUS Capture all victory hexes
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Antequera","earned_cp_format","Bonus Objective to capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ?? checked at scenario end ??
function Player1CustomSuccessB(action)
MessageBox("Player1CustomSuccessB")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) >= 5
end

-- ?? checked at scenario end ??
-- Objective 1: BONUS for capturing all victory hexes
function Player1CustomFailB(action)
MessageBox("Player1CustomFailB")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) < 5
end

-------------------------------------------------------------------
-- Objective 2: Sink the battleship Jaime I (Destroy unit ID #0) --
-------------------------------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} *
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Antequera","earned_cp_formatobj2","Bonus Objective to sink the Jaime I completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective2() **
function Objective2Condition(action)	-- ObjectiveStatusAction
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {10,15}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SR37mmBofors","HorseTransport",0,900},{"152mmM10-30","HorseTransport",0,900},{"152mmM10-30","HorseTransport",0,900},{"SR20mmVKPLvz36AA","HorseTransport",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"UNL35","",0,900},{"I-15","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition() **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed); lib.UpgradeHeroes(0) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, sr_spawn_zoneE, waves[math.random(#waves)])
end

---------------
-- Artillery --
---------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Antequera","string_4","<bi>Oberleutnant Wagner: </>Mein General, some of our forces have found a hidden Republican depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

----------------
-- 3x bombers --
----------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureAF(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(bombers.loc, action.flag)) then
		lib.SpawnWave(0, bombers.zone, bombers.units, true)	-- create & place player units as auxiliary
		TutorialMessage(NSLOCTEXT("scenario_Antequera","string_3","<bi>Oberleutnant Wagner: </>Antequera Airfield secured.  Ju-52 bomber conversions deploying for combat."))
	end
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
