-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 3 victory hexes	(19;5)(13;17)(18;17)(24;19)(16;31)
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Capture victory hexes	Capture Badajoz (5;18)

-- 6 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)	{if AlwaysTrue()}		-- 3 CP = UNL35 and Trubia Naval
	-- 1x	NemesisHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 1x	NemesisTimer(NewRoundAction) {if NemesisTimer()}	-> NemesisWarning()
	-- 1x	NemesisDeath(NewRoundAction) {if Condition2()}		-> Effect2()

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

------------------
-- Enemy heroes --
------------------

nem_unit=33	-- Nemesis is unit ID #33, per scenario

nemesis_hero = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.Butcher, UnitTrait.TenaciousDefender}}	-- tank "Comandante Vega" NW of Albuquerque, per scenario
}

-- ** 1x Effect(NewRoundAction) **
function NemesisHero()
	lib.CreateAndAssignHeroes(p_SR, nemesis_hero)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 3,
	eqs = {{"UNL35",35},{"TrubiaNaval",35}}
}

-- ** Condition for OnStartGame() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** Effect(NewRoundAction) {if AlwaysTrue()} **
function OnStartGame()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Merida","difficult_choice","Mein General, the Spanish Nationalists have recently captured a number of enemy vehicles.  One type is a prototype light tank, and the other type is a reliable recon vehicle.  I think they're willing to let us use the equipment if you can convince them.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 3 Commendation Points for their stockpile of captured equipment?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Merida","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Merida","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Merida","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Merida","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Merida","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Merida","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-------------
-- Nemesis --
-------------

-- ** Condition for NemesisWarning() **
function NemesisTimer()
	return world.round == 4
end

-- ** 1x Effect(NewRoundAction) {if NemesisTimer()} **
function NemesisWarning(action)
	TutorialMessage(NSLOCTEXT("scenario_Merida","string_1","<bi>Oberleutnant Wagner: </>Heads up, mein General.  We've got eyes on a Republican officer on the field.  Apparently it's... Comandante Vega?"))
	TutorialMessage(NSLOCTEXT("scenario_Merida","string_2","<bi>Capitana Vega: </>Before you ask, yes, he is my brother.  But make no mistake; he will forever be our enemy.  He will never be forgiven for the side he has chosen and things he has done in this war!") , false)
	TutorialMessage(NSLOCTEXT("scenario_Merida","string_3","<bi>Capitana Vega: </>I urge utmost caution whenever you encounter his unit.  He is a most capable and relentless fighter.") , false)
end

-- ** Condition for Effect2() **
function Condition2()
	return world:GetUnit(nem_unit) == nil	-- Nemesis eliminated
end

-- ** 1x Effect(NewRoundAction) {ifCondition2()} **
function Effect2()
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then	-- was alive at scenario start
		campaign.nemesislives = false
		TutorialMessage(NSLOCTEXT("scenario_Merida","string_death","<bi>Capitana Vega: </>Rest in peace, my misguided brother."))
	end
end

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Merida","earned_cp_format","Bonus Objective to capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------------------
-- Objective 2: Capture Badajoz --
----------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Merida","earned_cp_formatobj2","Bonus Objective to capture Badajoz completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
