-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 1 Objective defined in scenario:
	-- 0 @end	Control 5 victory hexes	(14;2)(14;5)(17;10)(10;14)(21;14)(17;18)(11;24)(15;28)(9;29)

-- 8 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)			{if AlwaysTrue()}
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	NemesisHeroes(NewRoundAction)										-> NemesisHero()
	-- 1x	TimedWarning(StartTurnAction)		{if TimedMessageCondition()}	-> TimedMessageEffect()
	-- 1x	Turn 2 Verdeja(NewRoundAction)		{if IsThirdTurn()}				-> Turn3Landing()
	--		NewRound(NewRoundAction)			{if EmptyCondition()}			-> OnNewRound()
	-- 1x	NemesisCheck(NewRoundAction)
	-- 1x	NemesisDeath(DeathAction|Surrender)	{if Condition2()}				-> Effect2()

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

VHs = {{14,2},{25,2},{14,5},{17,10},{10,14},{21,14},{17,18},{11,24},{15,28},{9,29}}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{22,2},{22,3},{22,4},{22,5},{22,6},{23,6},{22,7},{23,7},{24,7},{25,7},{26,7},{23,8},{26,8}}
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=43, traits={UnitTrait.Unyielding}},	-- rcn between Hill 24 & Hill 28, per scenario
	{unit_id=60, traits={UnitTrait.Unyielding}} 	-- inf "Commissar Hans Beimler" in Madrid, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

nem_unit=64	-- Nemesis is unit ID #64, per scenario

nemesis_hero = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.Butcher, UnitTrait.TenaciousDefender}}	-- tank "Comandante Vega" NE Madrid, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero (nemesis)
function NemesisHero()
	if (campaign.nemesislives == true) then
		lib.CreateAndAssignHeroes(p_SR, nemesis_hero)
	end
end

-- ** 1x Effect(NewRoundAction) **
function NemesisCheck()
	if (campaign.nemesislives == false) then
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis eliminated previously, remove unit from scenario
	end
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {10,13,17}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SRMilitia","",0,900},{"SRMilitia","",0,900},{"SRMilitia","",0,900},{"TrubiaNaval","",0,900},{"UNL35","",0,900},{"UNL35","",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"PolikarpovI16","",0,900}},
	{{"SRColonial","",0,900},{"SRColonial","",0,900},{"SRColonial","",0,900},{"SRColonial","",0,900},{"T26","",0,900},{"T26","",0,900},{"BT5","",0,900},{"BT5","",0,900},{"PolikarpovI16","",0,900}},
	{{"SRMilitia","",0,900},{"SRInfantry","",0,900},{"SRColonial","",0,900},{"SREngineers","",0,900},{"BA6","",0,900},{"T26","",0,900},{"BT5","",0,900},{"TrubiaNaval","",0,900},{"BilbaoM1932","",0,900},{"PolikarpovI16","",0,900}}
}

-- ** Condition for TimedMessageEffect() **
function TimedMessageCondition()
	return world.round == 10
end

-- ** 1x Effect(StartTurnAction) {if TimedMessageCondition()} **
function TimedMessageEffect()
	TutorialMessage(NSLOCTEXT("scenario_EarlyMadrid","string_1","<bi>Oberleutnant Wagner: </>Mein General, there are reports of large Republican reinforcements mustering within Madrid.  We might want to slow our advance to prepare for major counterattacks."))
end

------------------------------------------------------------------------
-- Objective 0: Control Five Victory Hexes at the end of the scenario --
------------------------------------------------------------------------

-- ** Condition for Objective 0 success **
function Player1CustomSuccess(action)
MessageBox("Player1CustomSuccess")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) >= 5
end

-- ** Condition for Objective 0 failure **
function Player1CustomFail(action)
MessageBox("Player1CustomFail")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) < 5
end

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, zones[math.random(#zones)], waves[math.random(#waves)])
end

---------------
-- Gift unit --
---------------

gift = {
	cps = 2,
	units= {{"Verdeja2","",0,0}},
	zone = {{4,31},{5,31},{6,31},{7,31},{4,32},{5,32},{6,32},{7,32},{8,32},{9,32},{10,32}}
}
uniquetank = false

-- ** Condition for OnStartGame() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** Effect(NewRoundAction) {if AlwaysTrue()} **
function OnStartGame()
	if (campaign.comm_points < gift.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_EarlyMadrid","difficult_choice","Mein General, some Spanish engineers have proposed a new tank development project, codename Verdeja.  They would like our support for the project, and are prepared to offer us a very special unit, and the technical knowledge to maintain it, in return.  I have seen the specifications, and they are very impressive.  In my opinion, this is not an opportunity we should neglect!\n\nYou have %d Commendation Points.\n\nWould you like to exchange 2 Commendation Points for this unique unit?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_EarlyMadrid","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_EarlyMadrid","option1_tooltip","The unit will be ready on turn 2")
		},
		{
			title  = NSLOCTEXT("scenario_EarlyMadrid","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_EarlyMadrid","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - gift.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)

		uniquetank = true
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_EarlyMadrid","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_EarlyMadrid","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-- ** Condition for Turn3Landing() **
function IsThirdTurn()
	return world.round == 3
end

-- ** 1x Effect(NewRoundAction) {if IsThirdTurn()} **
function Turn3Landing(action)
	if (uniquetank == true) then
		TutorialMessage(NSLOCTEXT("scenario_EarlyMadrid","string_2","The Verdeja unique tank has arrived from the South."))
		lib.SpawnWave(0, gift.zone, gift.units)	-- create & place player unit
	end
end

-------------
-- Nemesis --
-------------

-- ** Condition for Effect2() **
function Condition2()
	return world:GetUnit(nem_unit) == nil	-- Nemesis eliminated
end

-- ** 1x Effect(DeathAction|Surrender) {if Condition2()} **
function Effect2()
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then	-- was alive at scenario start
		campaign.nemesislives = false
		TutorialMessage(NSLOCTEXT("scenario_EarlyMadrid","string_death","<bi>Capitana Vega: </>Rest in peace, my misguided brother."))
	end
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
