-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 3 Objectives defined in scenario:
	-- 0 @end	Control 4 victory hexes	(25;7)(23;13)(6;18)(25;24)(14;26)(24;26)
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Custom objective		EscortSuccess() | EscortFailure()

-- 4 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}
	-- 		PrisonCaptured(CaptureFlagAction)								-> OnCapturePrison()

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

VHs = {{25,7},{23,13},{6,18},{25,24},{14,26},{24,26}}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

prison = {
	loc =  {{6,3}},	-- NW corner, per scenario
	units= {{"ESInfantry","",0,0}},
	zone = {{6,1},{7,1},{8,1}}
}
escort = {
	unit = -1,
	zone = {{26,27},{27,27},{26,28},{27,28},{28,28},{26,29},{27,29}}
}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{28,1},{29,2},{31,2},{32,2},{31,3},{32,4},{33,4},{32,5},{33,5},{33,6},{34,6},{34,8}},	-- NE
	{{1,23},{2,25},{3,25},{4,25},{3,26},{5,26},{3,27},{4,27},{5,27},{6,28},{6,29},{7,30}}	-- SW
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=57, traits={UnitTrait.Readiness, UnitTrait.DoubleAttack}}	-- ftr in SW Republic Camp, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

------------------------------------------
-- Objective 0: Control 4 victory hexes --
------------------------------------------

-- ?? checked at scenario end ??
function Player1CustomSuccess(action)
MessageBox("Player1CustomSuccess")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) >= 4
end

-- ?? checked at scenario end ??
function Player1CustomFail(action)
MessageBox("Player1CustomFail")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) < 4
end

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_CorunnaRoad","earned_cp_formatobj1","Bonus Objective to capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-------------------------------------------------------
-- Objective 2: Escort Nationalist Captive to Safety --
-------------------------------------------------------

-- ** Effect(CaptureFlagAction) **
function OnCapturePrison(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(prison.loc, action.flag)) then
		TutorialMessage(NSLOCTEXT("scenario_CorunnaRoad","string_1","Nationalist prisoner liberated.  We're ready to transport them to safety."))
		local spawned_ids = lib.SpawnWave(0, prison.zone, prison.units, true)	-- create and place player unit as auxiliary
		escort.unit = spawned_ids[1]	-- change -1 sentinel
	end
end

message_shown = false

-- ** Condition for Objective 2 success **
function EscortSuccess()
	if (escort.unit == -1) then return false end

	local unit = world:GetUnit(escort.unit)
	if (unit == nil) then return false end

	local success = lib.IsItemInTable(escort_zone, unit.position)
	if (success) then
		if (not message_shown) then
			message_shown = true

			local comm = 2
			campaign.comm_points = lib.UpdateCommendationPoints(comm)
			MessageBox(string.format(tostring(NSLOCTEXT("scenario_CorunnaRoad","earned_cp_format","Bonus Objective to escort prisoner completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
		end
	end
	return success
end

-- ** Condition for Objective 2 failure **
function EscortFailure()
	return escort.unit ~= -1 and world:GetUnit(escort.unit) == nil	-- unit was destroyed
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {6,12,19}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SRMilitia","",0,900},{"SRMilitia","",0,900},{"TrubiaNaval","",0,900},{"UNL35","",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"I-15","",0,900}},
	{{"SRColonial","",0,900},{"SRColonial","",0,900},{"SRColonial","",0,900},{"T26","",0,900},{"T26","",0,900},{"PolikarpovI16","",0,900}},
	{{"SRInfantry","",0,900},{"SRColonial","",0,900},{"SREngineers","",0,900},{"T26","",0,900},{"TrubiaNaval","",0,900},{"BilbaoM1932","",0,900},{"I-15","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed); lib.UpgradeHeroes(0) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, zones[math.random(#zones)], waves[math.random(#waves)])
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
