-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 2 Objectives defined in scenario:
	-- 0 		Hold hex(es) of Brunete for 23 turns	(8;29)(9;29)
	-- 1 opt	Capture all victory hexes	{{10,22},{14,14},{4,12},{13,3}}

-- 6 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)	{if EmptyCondition()}
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	NemesisHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)
	-- 1x	NemesisCheck(NewRoundAction)
	-- 1x	NemesisDeath(NewRoundAction) {if Condition2()}	-> Effect2()

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 3,
	eqs = {{"T26",25},{"PolikarpovI16",25}}
}

-- ** Condition for OnStartGame() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- 1x Effect(NewRoundAction) {if EmptyCondition()} **
function OnStartGame()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Brunete","difficult_choice","Mein General, the Spanish Nationalists have recently captured a wealth of Soviet made T-26 tanks and I-16 fighters!  They're willing to let us use the equipment if you can convince them.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 3 Commendation Points for their stock of captured equipment?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Brunete","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Brunete","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Brunete","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Brunete","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Brunete","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Brunete","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=52, traits={UnitTrait.IncMaxOverstrength, UnitTrait.Unyielding}}	-- inf "Brigada Abraham Lincoln" NW of Brunete, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

nem_unit=86	-- Nemesis is unit ID #86, per scenario

enemy_nemesis = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.Butcher, UnitTrait.TenaciousDefender}}	-- tank "Comandante Vega" NW of Torrelodones, per scenario
}

-- ** 1x Effect(NewRoundAction) **
function NemesisHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_nemesis)
end

-------------
-- Nemesis --
-------------

-- ** 1x Effect(NewRoundAction) **
function NemesisCheck()
	if (campaign.nemesislives == false) then
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis eliminated previously, remove unit from scenario
	end
end

-- Nemesis eliminated:

-- ** Condition for Effect2() **
function Condition2()
	return world:GetUnit(nem_unit) == nil	-- Nemesis eliminated
end

-- ** 1x Effect(NewRoundAction) {if Condition2()} **
function Effect2()
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then	-- was alive at scenario start
		campaign.nemesislives = false
		TutorialMessage(NSLOCTEXT("scenario_Brunete","string_death","<bi>Capitana Vega: </>Rest in peace, my misguided brother."))
	end
end

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** 1x OnObjective1(ObjectiveStatusAction) **
function OnObjective1(action)
	if (action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success) then
		local comm = 1
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		MessageBox(string.format(tostring(NSLOCTEXT("scenario_Brunete","earned_cp_format","Bonus Objective to capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
	end
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
