-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 2 Objectives defined in scenario:
	-- 0 		Hold Zaragosa for 17 turns		(5;5)
	-- 1 opt	Guard unit Commander Vasquez	Unit ID #0

-- 3 Triggers defined in scenario:
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	PrestigeSink(StartTurnAction)
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{16,1},{17,1},{18,1},{19,1},{21,1},{22,1},{23,2},{23,3},{24,3},{25,3}},	-- N
	{{26,13},{27,13},{26,14},{27,14},{25,15},{26,15},{26,16},{27,16},{26,17},{27,17},{27,18},{28,18}},	-- E
	{{15,26},{16,26},{17,26},{18,26},{12,27},{13,27},{15,27},{16,27},{17,27},{18,27},{14,28},{15,28},{16,28}},	-- S
	{{1,23},{2,23},{3,23},{3,24},{4,24},{4,25},{3,26},{4,26},{2,27},{3,27},{3,28}}	-- SW
}

--------------
-- Triggers --
--------------

-------------------
-- Prestige Sink --
-------------------

-- ** 1x Effect(StartTurnAction) **
function PrestigeSink()
	local message = string.format(tostring(NSLOCTEXT("scenario_Zaragoza","difficult_choice","Mein General, request coming in from our Nationalist allies.  The war has disrupted many civil services across Spain, and there is a severe lack of qualified workers to repair complex systems.  As a result they've asked if we can spare some of our maintenance crews to assist in rebuilding civilian infrastructure.  I estimate the amount of support they've requested will halve our resources, so we should not make this decision lightly.  If we do help them though, it should dramatically increase our influence in the future.\n\nYou have %d Commendation Points.\n\nWould you like to exchange HALF of your total prestige for 12 Commendation Points?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Zaragoza","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Zaragoza","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Zaragoza","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Zaragoza","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 12
		campaign.comm_points = lib.UpdateCommendationPoints(comm)

		local p = world:GetPlayer(player)
		p.prestige = math.ceil(p.prestige / 2)  -- remove 50% of prestige
		-- p.prestige = p.prestige * 70 / 100 -- remove 30% of prestige
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Zaragoza","choice_made1","You choose to assist, offering half of your existing supplies.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Zaragoza","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-------------------------------------------------
-- Objective 1: Commander Vasquez must survive --
-------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x OnObjective1(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Zaragoza","earned_cp_format","Bonus Objective for Vasquez surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {4,8,12,13}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SRMilitia","",0,900},{"SRMilitia","",0,900},{"TrubiaNaval","",0,900},{"UNL35","",0,900},{"SRInfantry","",0,900},{"SRInfantry","",0,900},{"122mm M10-30","HorseTransport",0,900},{"I-15","",0,900}},
	{{"SRColonial","",0,900},{"SRColonial","",0,900},{"SRColonial","",0,900},{"T26","",0,900},{"T26","",0,900},{"152mmM10-30","HorseTransport",0,900},{"PolikarpovI16","",0,900}},
	{{"SRInfantry","",0,900},{"SRColonial","",0,900},{"SREngineers","",0,900},{"T26","",0,900},{"TrubiaNaval","",0,900},{"BilbaoM1932","",0,900},{"122mm M10-30","HorseTransport",0,900},{"I-15","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** OnNewRound(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, zones[math.random(#zones)], waves[math.random(#waves)])
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
