-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 2 Objectives defined in scenario:
	-- 0 @end	Control Teruel at the end of the scenario	(19;18)
	-- 1 opt	Custom objective	EscortSuccess() | EscortFailure()

-- 5 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)			{if AlwaysTrue()}
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	EnemyHero2(NewRoundAction)
	-- 1x	Turn3Landing(StartTurnAction)		{if IsThirdTurn()}
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

VHs = {{19,18}}		-- Teruel, per scenario

escort_zone = {{2,5},{3,5},{2,6},{3,6},{4,6},{2,7},{3,7}}
escort_unit = 50	-- unit ID #, per scenario

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{27,18},{28,18},{26,19},{27,19},{26,20},{27,20},{28,20},{25,21},{26,21},{27,21},{25,22},{26,22},{27,22},{24,23},{25,23},{26,23},{24,24},{25,24}}	-- S
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=18, traits={UnitTrait.ShockTactics}},	-- art in Muleton, per scenario
	{unit_id=60, traits={UnitTrait.DoubleAttack}} 	-- art in La Meula, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero2()
--	MessageBox("EnemyHero2()")	-- @TODO: remove
end

---------------
-- Gift unit --
---------------

gift = {
	cps  = 3,
	units= {{"PanzerIIA","",0,0}},
	zone = {{4,3},{5,4},{6,4},{4,5},{5,6},{5,7},{6,8},{5,9},{2,10},{3,10},{4,10},{5,10}}
}
uniquetank = false

-- ** Condition for OnStartGame() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** 1x Effect(NewRoundAction) {if AlwaysTrue()} **
function OnStartGame()
	if (campaign.comm_points < gift.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Teruel","difficult_choice","Mein General, I've just learned that secret combat trials for the new Panzer II just finished, and Berlin has requested Franco return it to Germany for further evaluation.  If you apply some of your influence, I think you can get the unit transfered to our command instead!\n\nYou have %d Commendation Points.\n\nWould you like to exchange 3 Commendation Points for this advanced unit?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Teruel","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Teruel","option1_tooltip","The unit will be ready on turn 2")
		},
		{
			title  = NSLOCTEXT("scenario_Teruel","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Teruel","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - gift.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)

		uniquetank = true
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Teruel","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Teruel","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-- ** Condition for Turn3Landing() **
function IsThirdTurn()
	return world.round == 3
end

-- ** 1x Effect(StartTurnAction) {if IsThirdTurn()} **
function Turn3Landing(action)
	if (uniquetank == true) then
		TutorialMessage(NSLOCTEXT("scenario_Teruel","string_2","The Panzer II A tank has arrived from the West."))
		lib.SpawnWave(0, gift.zone, gift.units)	-- create & place player unit
	end
end

------------------------------------------------
-- Objective 1: Escort Medical Unit to Safety --
------------------------------------------------

message_shown = false

-- ** Condition for Objective 1 success **
function EscortSuccess()
	local unit = world:GetUnit(escort_unit)
	if (unit == nil) then return false end

	local success = lib.IsItemInTable(escort_zone, unit.position)
	if (success) then
		if (not message_shown) then
			message_shown = true

			local comm = 2
			campaign.comm_points = lib.UpdateCommendationPoints(comm)
			MessageBox(string.format(tostring(NSLOCTEXT("scenario_Teruel","earned_cp_format","Bonus Objective to escort Medic completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
		end
	end
	return success
end

-- ** Condition for Objective 1 failure **
function EscortFailure()
	return escort_unit ~= -1 and world:GetUnit(escort_unit) == nil	-- unit was destroyed
end

-- ?? checked at scenario end ??
function Player1CustomSuccess(action)
MessageBox("Player1CustomSuccess")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) > 0
end

-- ?? checked at scenario end ??
function Player1CustomFail(action)
MessageBox("Player1CustomFail")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) < 1
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {11}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SRMilitia","",0,900},{"SRMilitia","",0,900},{"TrubiaNaval","",2,900},{"UNL35","",0,900},{"SRInfantry","",1,900},{"SRInfantry","",1,900},{"122mm M10-30","HorseTransport",1,900},{"SRColonial","", 5, 2900},{"SRColonial","",2,900},{"SRColonial","",2,900},{"T26","",2,900},{"T26","",2,900},{"152mmM10-30","HorseTransport",2,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy waves
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed); lib.UpgradeHeroes(0) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, zones[math.random(#zones)], waves[math.random(#waves)])
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
