-- Players:
	-- 0 [H]:	Condor Legion, Italy
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2

-- 2 Objectives defined in scenario:
	-- 0 		Hold 3 victory hexes		(3;4)(9;5)(14;9)(5;15)(12;16)(15;21)(17;26)(15;30)(13;33)(6;35)
	-- 1 opt	Capture 10 victory hexes	(3;4)(9;5)(14;9)(5;15)(12;16)(15;21)(17;26)(15;30)(13;33)(6;35)

-- 7 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	NemesisHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)
	-- 1x	NemesisCheck(NewRoundAction)
	-- 1x	NemesisDeath(NewRoundAction)	{if Condition2()}	-> Effect2()
	-- 		OnNewRound(NewRoundAction)		{if EmptyCondition()}
	-- 1x	Galland(NewRoundAction)			{if AlwaysTrue()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{20,3},{21,3},{21,4},{22,4},{21,5},{22,5},{22,6},{23,6},{22,7},{23,7},{22,8},{24,8},{21,9},{22,9},{23,9}},
	{{22,17},{23,17},{24,17},{22,18},{24,18},{22,19},{23,19},{24,19},{23,20},{24,20},{25,20},{23,21},{24,21},{25,21}},
	{{23,25},{24,25},{25,25},{24,26},{25,26},{22,27},{23,27},{22,28},{23,28},{24,28}},
	{{21,35},{22,35},{23,35},{21,36},{22,36},{23,36},{20,37},{21,37},{22,37},{21,38},{22,38},{21,39},{22,39}}
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 66, traits={UnitTrait.AggressiveCounterattack}},	-- bmr Tupolev, a/f NE of Ribarroja & Flix, per scenario
	{unit_id= 98, traits={UnitTrait.Camouflage}},	-- art in fort, NE of Mora de Ebro, per scenario
	{unit_id=129, traits={UnitTrait.LastStand}},	-- rcn NE of Tivissa, per scenario
	{unit_id= 72, traits={UnitTrait.LastStand}} 	-- inf in camp E of Benisane, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
end

nem_unit=145	-- Nemesis is unit ID #145 "Comandante Vega", per scenario

nemesis_hero = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.Butcher, UnitTrait.TenaciousDefender}}	-- tank "Comandante Vega" in SE camp, per scenario
}

-- ** 1x Effect(NewRoundAction) **
function NemesisHero()
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then
		lib.CreateAndAssignHeroes(p_SR, nemesis_hero)
	end
end

-- ** 1x NemesisCheck(NewRoundAction) **
function NemesisCheck()
	if (campaign.nemesislives == false) then
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis eliminated previously, remove unit from scenario
	end
end

-------------
-- Nemesis --
-------------

-- ** Condition for Effect2() **
function Condition2()
	return world:GetUnit(nem_unit) == nil	-- Nemesis eliminated
end

-- ** 1x Effect(NewRoundAction) {if Condition2()} **
function Effect2()
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then	-- was alive at scenario start
		campaign.nemesislives = false
		TutorialMessage(NSLOCTEXT("scenario_BattleoftheEbro","string_death","<bi>Capitana Vega: </>Rest in peace, my misguided brother."))
	end
end

--------------------
-- Galland script --
--------------------

-- ** Condition for Galland() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** 1x Effect(NewRoundAction) {if AlwaysTrue()} **
function Galland()
	if (campaign.comm_points < 10) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_BattleoftheEbro","difficult_choice","Mein General, I've just learned that one of our best strike pilots is being recalled to Germany for promotion and reassignment.  I've spoken to Staffelkapitan Galland, and apparently he is not terribly interested in his new assignment and actually prefers to transfer to a fighter squadron.  He specifically requests something with a closed canopy, apparently.\n\nIt would take quite a bit of your influence, but if we could retain this pilot, I think he will enhance our fighter force to an unparalleled degree!  In my opinion, this is not an opportunity we should neglect.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 10 Commendation Points for this unique officer?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_BattleoftheEbro","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_BattleoftheEbro","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_BattleoftheEbro","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_BattleoftheEbro","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = -10
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		CreateGalland()
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_BattleoftheEbro","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_BattleoftheEbro","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

galland_hero = {
	{
		name=NSLOCTEXT("scenario_BattleoftheEbro","Adolf_Galland","Adolf Galland"),
		portrait="/Game/Gui/Common/Heroes/DE_AF_galland.DE_AF_galland",
		traits={UnitTrait.Legendary,UnitTrait.AimingAssistance,UnitTrait.Leadership},
		modifiers ={{type=Initiative,mod=2}},
		attack_modifiers={{type=TargetType.Air,mod=2}},
		unit_classes={UnitClass.Fighter,UnitClass.TacticalBomber}
	}
}

function CreateGalland()
	lib.CreateAndAssignHeroes(0, galland_hero)
end

-----------------------------------------------------------------
-- Objective 0: Hold at least Three Victory Hexes at all times --
-----------------------------------------------------------------

-- ?? checked at scenario end ??
function Player1CustomSuccess(action)
MessageBox("Player1CustomSuccess")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) > 8
end

-- ?? checked at scenario end ??
function Player1CustomFail(action)
MessageBox("Player1CustomFail")	-- DEBUG
	return action:GetActionClass() == "TurnsLimitAction" and lib.CountSide1VHs(VHs) < 9
end

-----------------------------------------------------------------------------
-- Objective 1: Control all Victory Hexes at any point during the scenario --
-----------------------------------------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) **
function OnObjective1(action)
	if (action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success) then
		local comm = 1
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		MessageBox(string.format(tostring(NSLOCTEXT("scenario_BattleoftheEbro","earned_cp_format","Bonus Objective to Hold all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
	end
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {3,5,9,11,14,19,22}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SRMilitia","HorseTransport",0,900},{"SRMilitia","HorseTransport",0,900},{"TrubiaNaval","",3,900},{"UNL35","",0,900},{"SRInfantry","HorseTransport",5,900},{"SRInfantry","HorseTransport",0,900},{"122mm M10-30","HorseTransport",0,900},{"I-15","",2,900},{"I-15","",2,900}},
	{{"SRColonial","HorseTransport",4,900},{"SRColonial","HorseTransport",0,900},{"SRColonial","HorseTransport",0,900},{"T26","",0,900},{"T26","",0,900},{"152mmM10-30","HorseTransport",0,900},{"PolikarpovI16","",2,2900},{"I-15","",5,900}},
	{{"SRInfantry","HorseTransport",0,900},{"SRColonial","HorseTransport",0,900},{"SREngineers","HorseTransport",4,900},{"T26","",0,900},{"TrubiaNaval","",0,900},{"BilbaoM1932","",5,900},{"122mm M10-30","HorseTransport",0,900},{"I-15","",0,900},{"PolikarpovI16","",0,900}}
}

-----------------------
-- Spawn enemy units --
-----------------------

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy waves
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed); lib.UpgradeHeroes(0) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_SR, zones[math.random(#zones)], waves[math.random(#waves)])
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
