-- Players:
	-- 0 [H]:	Condor Legion, Italy, Spain
	-- 1 [AI]:	Spain (Nationalists)
p_ES=1
	-- 2 [AI]:	Spanish Republic
p_SR=2
	-- 3 [AI]:	Communist Spain
p_CS=3

-- 2 Objectives defined in scenario:
	-- 0 	Capture all victory hexes
	-- 1 	Destroy all units

-- 5 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)			{if AlwaysTrue()}
	-- 1x	NemesisHero(NewRoundAction)
	-- 1x	NemesisCheck(NewRoundAction)
	-- 1x	NemesisDeath(DeathAction | SurrenderAction)	{if Condition2()}		-> Effect2()
	-- 1x	RevealHexes(NewRoundAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO0Spain

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=134, traits={UnitTrait.TenaciousDefender}}	-- tank "Colonel Segismundo Casado" NW Madrid, per scenario
}

nem_unit=52	-- Nemesis is unit ID #52, per scenario

nemesis_hero = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.Butcher, UnitTrait.TenaciousDefender, UnitTrait.IncMaxOverstrength}}	-- tank "Comandante Vega" SW of Madrid, per scenario
}

-- ** 1x Effect(NewRoundAction) **
function NemesisHero()
	lib.CreateAndAssignHeroes(p_SR, enemy_heroes)
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then
		lib.CreateAndAssignHeroes(p_CS, nemesis_hero)	-- @NOTE player change: now with Communists, per scenario
	end
end

-- ** 1x Effect(NewRoundAction) **
function NemesisCheck()
	if (campaign.nemesislives == false) then
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis eliminated previously, remove unit from scenario
	end
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 3,
	eqs = {{"UNL35",30},{"TrubiaNaval",30},{"T26",30},{"PolikarpovI16",30}}
}

-- ** Condition for OnStartGame() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** 1x Effect(NewRoundAction) {if AlwaysTrue()} **
function OnStartGame()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Madrid1939","difficult_choice","Mein General, the Spanish Nationalists have captured a number of enemy vehicles from their conquest of Catalonia.  They're willing to let us keep the equipment if you can convince them.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 3 Commendation Points for their large stock of captured equipment?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Madrid1939","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Madrid1939","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Madrid1939","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Madrid1939","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end

	local choice_made =
	{
		NSLOCTEXT("scenario_Madrid1939","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Madrid1939","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-------------
-- Nemesis --
-------------

-- ** Condition for Effect2() **
function Condition2()
	if (world.round == 1) then lib.UpgradeHeroes(0) end
	return world:GetUnit(nem_unit) == nil	-- Nemesis eliminated
end

-- ** 1x Effect(NewRoundAction) {if Condition2)} **
function Effect2()
	-- see: AO0Spain/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then	-- was alive at scenario start
		campaign.nemesislives = false
		TutorialMessage(NSLOCTEXT("scenario_Madrid1939","string_death","<bi>Capitana Vega: </>Rest in peace, my misguided brother."))
	end
end

----------------------
-- Ally AI commands --
----------------------

function AllyAttack()
	MessageBox("","Spanish Nationalist units will attack the nearest hostile victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderAttacker")
end

function AllyDefend()
	MessageBox("","Spanish Nationalist units will defend the nearest friendly victory hex.")
	lib.AllySetOrder(p_ES, "AIOrderDefender")
end

function AllyHoldPosition()
	MessageBox("","Spanish Nationalist units will hold position where they are.")
	lib.AllySetOrder(p_ES, "AIOrderHoldPositionFire")
end
