-- 1st scenario in campaign
-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Czechoslovakia
p_CZ=1

-- 3 Objectives defined in scenario:
	-- 0 		Capture 10 victory hexes	(15;8)(11;9)(21;11)(5;14)(23;15)(24;18)(2;23)(17;26)(7;30)(13;30)
	-- 1 opt	Destroy 0 units			unit IDs 29,26,32,30,45,37,48,40,31,47,46,49,50,25,2,0,1,24,53,42,52,43,44,28,41,33,35,39,34,36
	-- 2 		Capture all victory hexes

-- 5 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)
	-- 1x	PlayerHero(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	Turn2Spanish(NewRoundAction)		{if IsSecondTurn()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------------------------------
-- Objectives (Commendation Points) --
--------------------------------------

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=53, traits={UnitTrait.RiverAssault}}	-- tank SW of Prague, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_CZ, enemy_heroes)
end

---------------------
-- Player Hero(es) --
---------------------

-- @NOTE: these are repeated at start of AO1940 and AO1941 campaigns -
player_heroes = {
	-- the Units with these IDs exist only when _not_ importing Core units into campaign
	{unit_id= 8, name=NSLOCTEXT("scenario_Czechoslovakia","Volkhardt_Kautz","Volkhardt Kautz"), portrait="/Game/Gui/Common/Heroes/DE/de_in_11.de_in_11", traits={UnitTrait.QuadripleGun}},	-- art
	{unit_id=14, name=NSLOCTEXT("scenario_Czechoslovakia","Markus_von_Reuenthal","Markus von Reuenthal"), portrait="/Game/Gui/Common/Heroes/DE/de_in_02.de_in_02", traits={UnitTrait.Scavenger}},	-- tank
	{unit_id=15, name=NSLOCTEXT("scenario_Czechoslovakia","Siegfried_von_Bonde","Siegfried von Bonde"), portrait="/Game/Gui/Common/Heroes/DE/de_af_07.de_af_07", traits={UnitTrait.ArtySupport,UnitTrait.ATSupport}},	-- tank
	{unit_id=10, name=NSLOCTEXT("scenario_Czechoslovakia","Reinhardt_Herzog","Reinhardt Herzog"), portrait="/Game/Gui/Common/Heroes/DE/de_af_13.de_af_13", traits={UnitTrait.StrikesFirst}},	-- rcn
	{unit_id= 7, name=NSLOCTEXT("scenario_Czechoslovakia","Wolfgang_Schneider","Wolfgang Schneider"), portrait="/Game/Gui/Common/Heroes/DE/de_af_14.de_af_14", traits={UnitTrait.ZeroSlots}},	-- art
	{unit_id=19, name=NSLOCTEXT("scenario_Czechoslovakia","Ludwig_Mittermeier","Ludwig Mittermeier"), portrait="/Game/Gui/Common/Heroes/DE/de_in_13.de_in_13", traits={UnitTrait.Evasive}} 	-- inf eng
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, player_heroes)
end

-- ** 1x Effect(NewRoundAction) **
function OnStartGame()
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Czechoslovakia","current_cp_format2","In this campaign, you can earn Commendation Points by completing bonus objectives. Opportunities to exchange Commendation Points for various rewards will be offered as the campaign progresses.\n\nYou begin this campaign with %d Commendation Points.")), campaign.comm_points))
end

---------------
-- Gift unit --
---------------

-- ** Condition for Turn2Spanish() **
function IsSecondTurn()
	return world.round == 2	-- @TODO: and not campaign.azul
end

-- ** 1x Effect(NewRoundAction) {if IsSecondTurn()} **
function Turn2Spanish(action)
	TutorialMessage(NSLOCTEXT("scenario_Czechoslovakia","string_SPI1","<bi>Hauptmann Wagner: </>Special reinforcements have arrived, mein General.  For Germany's contribution to the Spanish Civil War, we've been granted a special unit of Spanish soldiers."))
	TutorialMessage(NSLOCTEXT("scenario_Czechoslovakia","string_SPI2","<bi>Hauptmann Wagner: </>It seems their unit is especially skilled at close combat encounters.  Their talents should prove quite useful in urban conflict zones."), false)
	lib.SpawnWave(0, {{9,7},{10,7},{9,8},{10,8}},{{"AzulInfantry","OpelBlitz",0,500}})	-- create & place player unit
end

-----------------------------------------
-- Objective 0: Avoid destroying units --
-----------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success	-- "Success" = destroyed at least one
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = -5
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Czechoslovakia","earned_cp_format","Bonus Objective to destroy zero enemy units failed.\nLost Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
