-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	France
p_FR=1

-- 3 Objectives defined in scenario:
	-- 0 		Custom objective: deploy 1 minefield	Player1CustomSuccess() | Player1CustomFail()
	-- 1 opt	Custom objective: deploy 3 minefields	Player1CustomSuccess3() | Player1CustomFail3()
	-- 2 opt	Custom objective: deploy 6 minefields	Player1CustomSuccess6() | Player1CustomFail6()

-- 7 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	KerscherHero(NewRoundAction)	{if AlwaysTrue()}
	-- 1x	MineHero(NewRoundAction)
	-- 		OnMineLaying(MoveAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{27,20}},	-- supply depot NE of Sarreinsming, per scenario
	eqs = {{"CharB1",5}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

mine_locations =	-- [1] is VP location, [2] is table of locations for (up to 8) mines
{
	{{4,18},  {{8,15},{8,16},{7,17},{1,18},{1,19},{5,19},{2,20},{3,20}}},	-- around Ippling
	{{7,23},  {{4,24},{9,24},{7,25},{8,25},{5,26},{7,26}}},					-- around Roadway SE of Ippling
	{{14,17},{{16,15},{18,16},{18,18},{11,19},{16,19},{13,20},{15,20}}},	-- around Sarreguemines
	{{23,18},{{25,17},{25,18},{18,19},{24,19},{20,20},{23,20}}},			-- around Roadway ESE of Sarreguemines
	{{21,11},{{24,9},{25,10},{24,11},{24,12},{19,13},{22,13},{21,14}}},		-- around Roadway NE of Sarreguemines
	{{25,4},  {{27,3},{28,3},{28,4},{27,5},{26,6},{27,6},{23,7}}}			-- around Bliesbruck
}
completed_mine_locations = {}
mines_deployed = 0

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=41, traits={UnitTrait.ATSupport}},	-- tank "Corporal Durand" SE of Bliesbruck, per scenario
	{unit_id=42, traits={UnitTrait.Readiness}}	-- tank "Sergeant Durand" NE of Bliesbruck, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_heroes)
end

-----------------
-- Mine heroes --
-----------------

mine_layers = {38,39,40}	-- unit IDs, per scenario

mine_heroes = {
	-- minelaying trucks:
	{unit_id=38, name = NSLOCTEXT("scenario_Sarreguemines","Sips","Sips"),   traits={UnitTrait.NoSplit}},
	{unit_id=39, name = NSLOCTEXT("scenario_Sarreguemines","Sjin","Sjin"),   traits={UnitTrait.NoSplit}},
	{unit_id=40, name = NSLOCTEXT("scenario_Sarreguemines","Irvin","Irvin"), traits={UnitTrait.NoSplit}}
}

-- ** 1x Effect(NewRoundAction) **
function MineHero()
	lib.CreateAndAssignHeroes(0, mine_heroes, true)	-- create silently, without usual Hero pop-up
end

---------------------
-- Player Hero(es) --
---------------------

-- ** Condition for Kerscher() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** Effect(NewRoundAction) {if AlwaysTrue()} **
function Kerscher()
	if (campaign.comm_points < 5) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Sarreguemines","difficult_choice","Mein General, I just learned that one of our Feldwebels is due to transfer to Poland.  I've come to know him, and I think Feldwebel Kerscher has a promising career as a tank commander ahead of him.  Using your considerable infleunce, I'm certain that issuing him a promotion to Oberfeldwebel would allow us to keep him in our ranks.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 5 Commendation Points for this unique officer?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Sarreguemines","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Sarreguemines","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Sarreguemines","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Sarreguemines","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = -5
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		CreateKerscher()
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Sarreguemines","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Sarreguemines","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

kerscher_hero = {
	{
		name=NSLOCTEXT("scenario_Sarreguemines","Albert_Kerscher","Albert Kerscher"),
		portrait="/Game/Gui/Common/Heroes/de_in_kerscher.de_in_kerscher",
		traits={UnitTrait.Famous,UnitTrait.TankKiller,UnitTrait.AggressiveCounterattack},
		modifiers={{type=Initiative,mod=3}},
		attack_modifiers={{type=TargetType.Hard,mod=10},{type=TargetType.Soft,mod=2}},
		defense_modifiers={{type=Ground,mod=10}},
		unit_classes={UnitClass.Tank,UnitClass.AntiTank}
	}
}

function CreateKerscher()
	lib.CreateAndAssignHeroes(0,kerscher_hero)
end

-------------------------------------
-- Objective 0: Deploy 1 minefield --
-------------------------------------

-- ** Condition for Objective 0 Success **
-- ** checked at scenario end **
function Player1CustomSuccess(action)
	return action:GetActionClass() == "TurnsLimitAction" and mines_deployed >= 1
end

-- ** Condition for Objective 0 Failure **
-- ** checked at scenario end **
function Player1CustomFail(action)
	return action:GetActionClass() == "TurnsLimitAction" and mines_deployed < 1
end

--------------------------------------
-- Objective 1: Deploy 3 minefields --
--------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Sarreguemines","earned_cp_format","Bonus Objective to deploy 3 minefield clusters completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for Objective 1 Success **
function Player1CustomSuccess3(action)
	return mines_deployed >= 3
end

-- ** Condition for Objective 1 Failure **
function Player1CustomFail3(action)
	return action:GetActionClass() == "TurnsLimitAction" and mines_deployed < 3
end

--------------------------------------
-- Objective 2: Deploy 6 minefields --
--------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Sarreguemines","earned_cp_formatobj2","Bonus Objective to deploy 6 minefield clusters completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for Objective 2 Success **
function Player1CustomSuccess6(action)
	return mines_deployed >= 6
end

-- ** Condition for Objective 2 Failure **
function Player1CustomFail6(action)
	return action:GetActionClass() == "TurnsLimitAction" and mines_deployed < 6
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Sarreguemines","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

----------------------
-- Minelaying units --
----------------------

-- ** Effect(MoveAction) **
function OnMineLaying(action)
	-- Check if moved unit is one of mine layers
	if (not lib.IsItemInTable(mine_layers, action.unit)) then return end

	-- Check if we already planted mines in this location
	if (lib.IsItemInTable(completed_mine_locations, action.position)) then return end

	-- Check if we need to lay any mines in this hex
	local lay_hexes = nil
	for _,mine_location in ipairs(mine_locations) do
		if (mine_location[1] == action.position) then lay_hexes = mine_location[2]; break end
	end
	if (lay_hexes == nil) then return end

	-- 1. Spawn land mine units
	local player = 0
	local units = {{"LandMine","",0,0},{"LandMine","",0,0},{"LandMine","",0,0},{"LandMine","",0,0} }
	lib.SpawnWave(player, lay_hexes, units, true)	-- create & place mines as auxiliary
	-- 2. Increase the counter
	mines_deployed = mines_deployed + 1
	-- 3. Display message
	MessageBox("", string.format(tostring(NSLOCTEXT("scenario_Sarreguemines","mines_layed","Minefield cluster successfully deployed.\n\nTotal minefield clusters deployed is now %d.")), mines_deployed))
	-- 4. Remember that we've planted mines in this location
	table.insert(completed_mine_locations, action.position)
end
