-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	France
p_FR=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 3 victory hexes		(16;10)(9;11)(16;15)(6;17)(12;20)(7;24)
	-- 1 opt	Capture 6 victory hexes		""
	-- 2 opt	Capture 1 victory hex		(17;26)

-- 5 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)
	-- 		OnNewRound(NewRoundAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{17,27}},	-- St Avold, per scenario
	eqs = {{"CharB1",5}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{2,30},{3,30},{4,30},{5,30},{6,30},{7,30},{8,30},{16,30},{17,30},{18,30}}	-- SW
}

--------------
-- Triggers --
--------------

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {10,12}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"FRInfantry","HorseTransport",0,900},{"FRCavalry","",0,900},{"FRCavalry","",0,900},{"AMC35","",0,900},{"RenaultR35","",0,900},{"HotchkissH35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"MS406","",0,900},{"Breguet693","",0,900}},
	{{"FREngineers","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"FR75mmmle1897","HorseTransport",0,900},{"FR105mmmle1913","HorseTransport",0,900},{"Panhard178","",0,900},{"25mmSA34","HorseTransport",0,900},{"FR37mmmle30AA","HorseTransport",0,900},{"MS406","",0,900}},
	{{"FRInfantry","",0,900},{"FRInfantry","",0,900},{"FR75mmmle1897","HorseTransport",0,900},{"FR105mmmle1913","HorseTransport",0,900},{"Panhard178","",0,900},{"25mmSA34","HorseTransport",0,900},{"FR37mmmle30AA","HorseTransport",0,900},{"MS406","",0,900}},
	{{"FRCavalry","",0,900},{"FRCavalry","",0,900},{"FRInfantry","HorseTransport",0,900},{"FRInfantry","HorseTransport",0,900},{"FRInfantry","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"MS406","",0,900},{"Breguet693","",0,900}},
	{{"FT17","",0,900},{"FT17","",0,900},{"AMC35","",0,900},{"RenaultR35","",0,900},{"HotchkissH35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"Breguet693","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** 1x Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_FR, zones[math.random(#zones)], waves[math.random(#waves)])
end

------------------------------------------
-- Objective 1: Capture 6 victory hexes --
------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_WarndtForest","earned_cp_format","Bonus Objective to capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------------------
-- Objective 2: Raid St. Avold --
---------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_WarndtForest","earned_cp_formatobj2","Bonus Objective to raid St. Avold completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=10, traits={UnitTrait.Vigilant}}	-- cav "Captain Seydoux" in St Avold, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_heroes)
end

---------------------
-- Equipment cache --
---------------------

-- ** 1x Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_WarndtForest","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end
