-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	France
p_FR=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 5 victory hexes		(21;11)(16;16)(22;16)(19;17)(15;18)(17;22)(22;22)(23;25)(28;25)(20;27)(14;28)(16;30)(26;30)
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Capture 1 victory hex		(29;10)

-- 4 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{28,11}},	-- Orenthal, per scenario
	eqs = {{"CharB1",7}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Orenthal","earned_cp_format","Bonus Objective to capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

--------------------------------
-- Objective 2: Raid Orenthal --
--------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Orenthal","earned_cp_formatobj2","Bonus Objective to raid Orenthal completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=55, traits={UnitTrait.DoubleAttack, UnitTrait.DoubleSupport}},	-- art in Orenthal, per scenario
	{unit_id=41, traits={UnitTrait.CityFighter}},			-- inf in Orenthal, per scenario
	{unit_id=43, traits={UnitTrait.FearsomeReputation}},	-- inf in Orenthal, per scenario
	{unit_id=95, traits={UnitTrait.Camouflage}},			-- tank in fort zone SE of Loutzviller, per scenario
	{unit_id=96, traits={UnitTrait.TankKiller}} 			-- tank in fort zone SE of Loutzviller, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_heroes)
end

---------------------
-- Equipment cache --
---------------------

-- ** 1x Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Orenthal","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end
