-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	France - 3rd Army
p_FR_3=1
	-- 2 [AI]:	France - 4th Army
p_FR_4=2

-- 4 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex	(3;3)(14;10)
	-- 1 opt	Destroy 4 units			Unit IDs # 23,13,24,12
	-- 2 opt	Destroy 4 depots		Unit IDs # 29,30,33,31,32
	-- 3 opt	Destroy 4 hangars		Unit IDs # 28,42

-- 4 Triggers defined in scenario:
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 1x	OnObjective3(ObjectiveStatusAction)	{if Objective3Condition()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{6,14}},	-- char depot, per scenario
	eqs = {{"CharB1",5}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

--------------------------------------------
-- Objective 1: Eliminate French Sentries --
--------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Forbach","earned_cp_format","Bonus Objective to eliminate sentries completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

----------------------------------------
-- Objective 2: Destroy French Depots --
----------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Forbach","earned_cp_formatobj2","Bonus Objective to destroy French depots completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-----------------------------------------
-- Objective 3: Destroy French Hangars --
-----------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective3Condition()} **
function OnObjective3(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Forbach","earned_cp_formatobj3","Bonus Objective to destroy French hangars completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective3() **
function Objective3Condition(action)
	return action.side == 0 and action.objective == 3 and action.status == ObjectiveStatus.Success
end

---------------------
-- Equipment cache --
---------------------

-- ** 1x Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Forbach","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end
