-- Players:
	-- [H]:	Germany
	-- [AI]:	France - 3rd Army (SouthWest)
p_FR_3=1
	-- [AI]:	France - 4th Army (SouthEast)
p_FR_4=2

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 2 victory hexes		(5;11)(18;11)(20;11)(29;13)
	-- 1 opt	Capture 4 victory hexes		(5;11)(18;11)(20;11)(29;13)
	-- 2 opt	Capture 2 victory hexes		(31;19)(36;25)

-- 6 Triggers defined in scenario:
	-- 1x	OnStartGame(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Condition()}
	-- 1x	Dir(NewRoundAction)					{if AlwaysTrue()}
	-- 1x	OnSecondTurn(NewRoundAction)		{if IsSecondTurn()}
	-- 1x	Turn3Landing(NewRoundAction)		{if IsThirdTurn()}
	-- 		OnNewRound(NewRoundAction)			{if EmptyCondition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{2,27},{3,27},{4,28},{5,28},{6,28},{7,28},{8,28},{9,28},{4,29},{5,29},{6,29},{7,29},{8,29},{9,29},{9,30},{10,30}},	-- SW (p_FR_3)
	{{30,29},{31,29},{32,29},{33,29},{34,29},{35,29},{36,29},{37,29},{38,29},{30,30},{31,30},{32,30},{33,30},{34,30}}	-- SE (p_FR_4)
}

--------------
-- Triggers --
--------------

---------------------
-- Player Hero(es) --
---------------------

-- ** Condition for Dir() **
-- Not needed, but ** used in scenario **
function AlwaysTrue()
	return true
end

-- ** 1x Effect(NewRoundAction) {if AlwaysTrue()} **
function Dir()
	if (campaign.comm_points < 6) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Saarbrucken","difficult_choice","Mein General, I have been looking over our personel reports, and I noticed one of our riflemen is showing exceptional skill with a scoped weapon.  I think a promotion to single out Oleh Dir is an order, and any infantry unit he is attached too will greatly benefit from his expertise.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 6 Commendation Points for this unique sniper?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Saarbrucken","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Saarbrucken","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Saarbrucken","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Saarbrucken","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = -6
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		CreateUber()
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Saarbrucken","choice_made1","You decide to use some of your influence to promote this soldier.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Saarbrucken","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

dir_hero = {
	{
		name= NSLOCTEXT("scenario_Saarbrucken","Oleh_Dir","Oleh Dir"),
		portrait= "/Game/Gui/Common/Heroes/de_in_olehdir.de_in_olehdir",
		traits= {UnitTrait.ReducedSlots, UnitTrait.IncMaxOverstrength, UnitTrait.FastDeployment, UnitTrait.AimingAssistance, UnitTrait.PreciseOptics},
		modifiers= {{type = Initiative, mod = 2},{type = Spotting, mod = 1},{type = Speed, mod = 20}},
		attack_modifiers= {{type = TargetType.Soft, mod = 5}},
		defense_modifiers= {{type = Ground, mod = 10}},
		unit_classes= {UnitClass.Infantry}
	}
}

function CreateUber()
	lib.CreateAndAssignHeroes(0,dir_hero)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps  = 6,
	eqs  = {{"SomuaS35",25}},			-- to replace future losses
	units= {{"SomuaS35","",0,0}},		-- free unit
	zone = {{22,5},{23,5},{22,6},{23,6},{21,7},{22,7}}
}
uniquetank = false

-- ** Condition for OnSecondTurn() **
function IsSecondTurn()
	return world.round == 2
end

-- ** 1x Effect(NewRoundAction) {if IsSecondTurn()} **
function OnSecondTurn()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Saarbrucken","difficult_choice2","Mein General, our field mechanics just finished their inventory of French equipment we seized during the Orenthal raids.  They report that there are enough technical documents and spare parts to field a single unit of Somua S35 medium tanks.  Requisitioning enough custom parts to continue to keep it running will take more than a little bit of your influence with our quartermasters though.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 6 Commendation Points for this balanced tank unit?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice2")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Saarbrucken","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Saarbrucken","option1_tooltip","The unit will be ready on turn 3")
		},
		{
			title  = NSLOCTEXT("scenario_Saarbrucken","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Saarbrucken","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice2" ==> ProcessChoice2(player,choice)
end

function ProcessChoice2(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)

		uniquetank = true
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Saarbrucken","choice_made6","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Saarbrucken","choice_made7","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-- ** Condition for Turn3Landing() **
function IsThirdTurn()
	return world.round == 3
end

-- ** 1x Effect(NewRoundAction) {if IsThirdTurn()} **
function Turn3Landing(action)
	if (uniquetank == true) then
		TutorialMessage(NSLOCTEXT("scenario_Saarbrucken","string_SomuaS35","The repaired Somua S35 tank has arrived from the North."))
		lib.AddEquipments(0, trade.eqs, Captured)
		lib.SpawnWave(0, trade.zone, trade.units)	-- create & place player unit
	end
end

---------------------------------------------
-- Objective 1: Defend all 4 Victory Hexes --
---------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Saarbrucken","earned_cp_format","Bonus Objective to hold all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-------------------------------------------------
-- Objective 2: Raid French 4th Army Air Bases --
-------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Saarbrucken","earned_cp_formatobj2","Bonus Objective to raid French airfields completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {5,10,15,20}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"FRInfantry","HorseTransport",0,900},{"FRCavalry","",0,900},{"FRCavalry","",0,900},{"AMC35","",0,900},{"RenaultR35","",0,900},{"HotchkissH35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"MS406","",0,900},{"Breguet693","",0,900}},
	{{"FREngineers","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"FR75mmmle1897","HorseTransport",0,900},{"FR105mmmle1913","HorseTransport",0,900},{"Panhard178","",0,900},{"25mmSA34","HorseTransport",0,900},{"FR37mmmle30AA","HorseTransport",0,900}},
	{{"FRInfantry","",0,900},{"FRInfantry","",0,900},{"FR75mmmle1897","HorseTransport",0,900},{"FR105mmmle1913","HorseTransport",0,900},{"Panhard178","",0,900},{"25mmSA34","HorseTransport",0,900},{"FR37mmmle30AA","HorseTransport",0,900}},
	{{"FRCavalry","",0,900},{"FRCavalry","",0,900},{"FRInfantry","HorseTransport",0,900},{"FRInfantry","HorseTransport",0,900},{"FRInfantry","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"MS406","",0,900},{"Breguet693","",0,900}},
	{{"FT17","",0,900},{"FT17","",0,900},{"AMC35","",0,900},{"RenaultR35","",0,900},{"HotchkissH35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"MS406","",0,900},{"Breguet693","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	-- Determine the player to get the next wave
	-- Germany is player 0, so AI players are 1-2
	local player = math.random(p_FR_3, p_FR_4)	-- randomly choose Fr. 3rd Army (West) or 4th Army (East)
	-- Choose spawn zone based on player selected:
	local zone
	if (player == p_FR_3) then
		zone = zones[1]	-- SW
	else	-- p_FR_4
		zone = zones[2]	-- SE
	end
	lib.SpawnWave(player, zone, waves[math.random(#waves)])
end
