-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Poland
p_PO=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 2 victory hexes		(37;14)(35;18)(26;27)(14;30)
	-- 1 opt	Capture 4 victory hexes
	-- 2 		Capture 1 victory hex		(11;14)

-- 7 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)		{if Objective1Condition()}
	-- 1x	OnObjective2(ObjectiveStatusAction)		{if Objective2Condition()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)
	-- 		OnCaptureStoreHouse2(CaptureFlagAction)
	-- 1x	TimedMessageEffectRecon(NewRoundAction)	{if TimedMessageCondition()}
	-- 		OnNewRound(NewRoundAction)				{if EmptyCondition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

VHs = {{37,14},{35,18},{26,27},{14,30}}

Kutno = {{11,14}}

caches = {
	{	-- 1:
		loc = {{33,36}},	-- village SE corner, per scenario
		eqs = {{"SPwz29",7},{"7TPdw",7}}
	},
	{	-- 2:
		loc = {{40,32}},	-- vilage SE corner, per scenario
		eqs = {{"SPwz29",7},{"7TPdw",7}}
	}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{19,8},{20,8},{18,9},{19,9},{16,10},{17,10},{19,10},{16,11},{17,11},{18,11}}
}

--------------
-- Triggers --
--------------

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {10,12,17,19}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"PLCavalry","",0,900},{"PLCavalry","",0,900},{"105mmwz29","HorseTransport",0,900},{"TKS","",0,900},{"7TPjw","",0,900},{"PZLP11c","",0,900},{"PZLP11c","",0,900}},
	{{"PLInfantry","HorseTransport",0,900},{"PLInfantry","",0,900},{"PLCavalry","",0,900},{"40mmwz36AA","HorseTransport",0,900},{"TKS","",0,900},{"7TPjw","",0,900}},
	{{"PLInfantry","HorseTransport",0,900},{"PLInfantry","",0,900},{"PLCavalry","",0,900},{"40mmwz36AA","HorseTransport",0,900},{"SPwz29","",0,900},{"7TPdw","",0,900}},
	{{"PLEngineers","HorseTransport",0,900},{"PLEngineers","HorseTransport",0,900},{"37mmwz36","HorseTransport",0,900},{"40mmwz36AA","HorseTransport",0,900},{"105mmwz29","HorseTransport",0,900},{"105mmwz29","HorseTransport",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_PO, zones[math.random(#zones)], waves[math.random(#waves)])
end

-----------------------------------------------------------------------------
-- Objective 1: Control All Victory Hexes at any point during the scenario --
-----------------------------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Bzura","earned_cp_format","Bonus Objective to hold all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------
-- Objective 2: Raid Kutno --
-----------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Bzura","earned_cp_formatobj2","Bonus Objective to raid Kutno completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=90, traits={UnitTrait.ArtySupport, UnitTrait.Vigilant, UnitTrait.TankKiller}}	-- cav "General Kutrzeba" E of Gabin, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_PO, enemy_heroes)
end

---------------------
-- Equipment cache --
---------------------

-- @TODO: collapse these (since both get called upon any flag capture but have mutually exclusive locations), by
-- parameterizing the cache location and equipment table

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(caches[1].loc, action.flag)) then
		lib.AddEquipments(0, caches[1].eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Bzura","string_st1","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden Polish depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse2(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(caches[2].loc, action.flag)) then
		lib.AddEquipments(0, caches[2].eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Bzura","string_st2","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found another hidden Polish depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

------------------------
-- Messages to player --
------------------------
-- Rudel, turn 10

-- ** Condition for TimedMessageEffectRecon() **
function TimedMessageCondition()
	return world.round == 10
end

-- ** 1x Effect(NewRoundAction) {if TimedMessageCondition()} **
function TimedMessageEffectRecon()
	TutorialMessage(NSLOCTEXT("scenario_Bzura","string_recon1","<bi>Hauptmann Wagner: </>Mein General, one of our long range recon pilots has been making quite a fuss.  He has been clamoring for less time in reserve and even a transfer to a combat assignment.\n\nThere is nothing we can do about these requests at the moment, but perhaps in future we should regularly deploy recon aircraft to upcoming battles.  Perhaps that will placate him, while we determine if a transfer to a combat unit is appropriate for this particular pilot."))
end
