-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Poland
p_PO=1

-- 1 Objective defined in scenario:
	-- 0 		Capture all victory hexes

-- 5 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	TimedMessageEffectRecon(NewRoundAction)	{if TimedMessageCondition()}
	-- 1x	OnTurnFive()	{if IsTurnFiveCheck()}
	-- 1x	Turn9Landing()	{if IsTurnNine()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1939

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 48, traits={UnitTrait.Unyielding, UnitTrait.LastStand}},		-- inf "Juliusz Zulauf" W section obj, per scenario
	{unit_id=102, traits={UnitTrait.Camouflage, UnitTrait.LastStand}},		-- tank "Tadeusz Kutrzeba" E section, per scenario
	{unit_id=122, traits={UnitTrait.NoRetaliation, UnitTrait.LastStand}},	-- tank NE section, per scenario
	{unit_id= 96, traits={UnitTrait.NoRetreat, UnitTrait.NoSurrender}},		-- cav "Marian Porwit" E of hangars, per scenario
	{unit_id=104, traits={UnitTrait.NoRetreat, UnitTrait.NoSurrender}},		-- cav "Walerian Czuma" NE section, per scenario
	{unit_id=101, traits={UnitTrait.NoRetreat, UnitTrait.NoSurrender}},		-- cav "Straz Graniczna" E section, per scenario
	{unit_id= 46, traits={UnitTrait.DoubleSupport, UnitTrait.LastStand}} 	-- art "Kazimierz Baran" near hangars, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_PO, enemy_heroes)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps  = 4,	-- used 2x
	eqs  = {{"I-15",19},{"TKS",5},{"PZLP11c",18},{"PZLP37BLos",17}},
	units= {{"Il2Shturmovik","",0,0}},	-- also free unit
	zone = {{30,8},{31,8},{32,8},{31,17},{32,17},{33,17},{33,35},{34,35},{35,35}}	-- NE airfield, per scenario
}

search = false
uniqueair = false

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < (trade.cps*2)) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Warsaw","difficult_choice2","Mein General, I think there is something that requires your attention.  I hesitate to bring it up because it could just be a ruse, but I have a hunch that it is not.\n\nI believe there is a secret message imbedded in one of the Soviet communiques we recently intercepted!  If we have decoded it correctly, it seems to refer to secret test flights of a brand new aircraft, and they are hiding movement of the prototype by shipping it alongside a pile of captured Polish junk and old Soviet scrap.\n\nWith your permission, we could investigate the matter with a clandestine operation.  It would most likely take a considerable amount of your influence to arrange though.\n\nYou have %d Commendation Points.\n\nWould you like to use 8 Commendation Points to investigate this mystery?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Warsaw","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Warsaw","option1_tooltip","Outcome uncertain")
		},
		{
			title  = NSLOCTEXT("scenario_Warsaw","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Warsaw","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(0, trade.eqs, Captured)
		search = true
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Warsaw","choice_made1","Your investigation only uncovered the decoy convoy of captured junk.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Warsaw","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
end

-- ** Condition for OnTurnFive() **
function IsTurnFiveCheck()
	return world.round == 5
end

-- ** Effect(NewRoundAction) {if IsTurnFiveCheck()} **
function OnTurnFive()
	if (campaign.comm_points < trade.cps or search == false) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Warsaw","difficult_choice3","Mein General, I know you are disappointed we only found junk in our investigation, but I believe that was a sign that we were on the right track.  If this was truly a ruse, we should have not found anything at all!  With only a little more resources and effort, I am certain we can find this secret prototype.\n\nYou have %d Commendation Points.\n\nWould you like to use 4 Commendation Points to further investigate this mystery?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice2")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Warsaw","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Warsaw","option1_tooltip","Outcome uncertain")
		},
		{
			title  = NSLOCTEXT("scenario_Warsaw","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Warsaw","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice2" ==> ProcessChoice2(player,choice)
end

function ProcessChoice2(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		uniqueair = true	-- set
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Warsaw","choice_made6","You choose to continue the investigation.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Warsaw","choice_made7","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-- ** Condition for Turn9Landing() **
function IsTurnNine()
	return world.round == 9
end

-- ** Effect(NewRoundAction) {if IsTurnNine()} **
function Turn9Landing(action)
	if (uniqueair == true) then
		TutorialMessage(NSLOCTEXT("scenario_Warsaw","string_secretair","<bi>Hauptmann Wagner: </>Mein General, we found the prototype and enough technical information to field a single squadron of them for ourselves!  They will be deploying to the nearest eastern airfield as we speak."))
		lib.SpawnWave(0, trade.zone, trade.units)	-- create & place player unit
	end
end

------------------------
-- Messages to player --
------------------------
-- Rudel, turn 20

-- ** Condition for TimedMessageEffectRecon() **
function TimedMessageCondition()
	return world.round == 20
end

-- ** 1x Effect(NewRoundAction) {if TimedMessageCondition()} **
function TimedMessageEffectRecon()
	TutorialMessage(NSLOCTEXT("scenario_Bzura","string_recon2","<bi>Hauptmann Wagner: </>Mein General, sorry to interrupt, but that recon pilot is back with yet another transfer request.  I have taken the liberty of agreeing to send him back to Germany at the conclusion of our campaign.\n\nPerhaps after some time with an Aviation Training Regiment we might reconsider him for combat assignment."))
end
