-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Netherlands
p_NL=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex	(10;14)
	-- 1 opt	Capture 2 victory hexes	(6;33)(7;35)
	-- 2 opt	Destroy 11 units		unit IDs 0,1,2,3,4,5,6,108,109,110,111

-- 4 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{10,14}},	-- De Kooy Naval Airbase (fokker depot), per scenario
	eqs = {{"FokkerDXXI",30}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=103, traits={UnitTrait.PreciseOptics, UnitTrait.Vigilant}}	-- inf "Kapitein Bas" in forest E of Utrecht, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_NL, enemy_heroes)
end

-----------------------------------------------
-- Objective 1: Capture Valkenburg Airfields --
-----------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_ValkenburgRaid","earned_cp_format","Bonus Objective to Capture Valkenburg Airfields completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

--------------------------------------------------------------
-- Objective 2: Destroy all 11 Dutch aircraft on the ground --
--------------------------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_ValkenburgRaid","earned_cp_format2","Bonus Objective to destroy 11 Grounded Dutch Aircraft completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_ValkenburgRaid","string_C","<bi>Hauptmann Wagner: </>Mein General, our forces securing the Naval Airbase report that they captured several hangars of intact Dutch aircraft.  We've commandeered the contents and you can access them as captured equipment."))
	end
end
