-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Netherlands
p_NL=1

-- 2 Objectives defined in scenario:
	-- 0 		Capture 4 victory hexes	(6;9)(8;10)(15;15)(17;18)
	-- 1 opt	Capture 1 victory hex	(2;14)

-- 3 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 		AfterObj1(NewRoundAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 0, traits={UnitTrait.PhasedMovement}}, 	-- tank SW of Hill 14, per scenario
	{unit_id= 1, traits={UnitTrait.Readiness}},			-- rcn  SW of Hill 14, per scenario
	{unit_id=15, traits={UnitTrait.DoubleAttack}},		-- art  NE of Utrecht, per scenario
	{unit_id=22, traits={UnitTrait.FerociousDefense}}	-- inf  in Amersfoort, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_NL, enemy_heroes)
end

--------------------------------------------------------------
-- Objective 1: Capture Utrecht before the last Victory Hex --
--------------------------------------------------------------

uniquetank = false

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 3
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Grebbeberg","earned_cp_format","Bonus Objective to Capture Utrecht completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
	uniquetank = true	-- set
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 4,
	units= {{"Neubaufahrzeug","",0,0}},
	zone = {{26,6},{25,7},{26,8},{25,9},{25,10},{24,11},{25,12}}
}

-- ** 1x Effect(NewRoundAction) **
function AfterObj1()
	if (campaign.comm_points < trade.cps or uniquetank == false) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Grebbeberg","difficult_choice","Mein General, excuse the interruption, but I believe there is a matter of some interest that deserves your attention.  It seems that some prototype multi-turret tanks were deployed in the ongoing campaign in Norway, but their performance seems to have been rather disappointing.  Despite possessing considerable firepower, the tanks were found to be too vulnerable to enemy fire.\n\nI bring this to your attention, because the vehicles are apparently on their way to the scrapyard.  If you would prefer to get these Neubaufahrzeug transferred to your command instead, I am certain this can be arranged.  It will be too late for them to assist in this battle, but we will have them to keep for future actions.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 4 Commendation Points for this unique unit?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Grebbeberg","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Grebbeberg","option1_tooltip","The unit will arrive immediately")
		},
		{
			title  = NSLOCTEXT("scenario_Grebbeberg","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Grebbeberg","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.SpawnWave(0, trade.zone, trade.units)	-- create & place player unit
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Grebbeberg","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Grebbeberg","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
	uniquetank = false	-- clear (in either case)
end
