-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Belgium
p_BE=1
	-- 2 [AI]:	France
p_FR=2

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex	(17;14)
	-- 1 opt	Capture 1 victory hex	(19;27)
	-- 2 opt	Destroy 20 units		unit IDs 19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56

-- 6 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}
	-- 1x	OnTurn16(StartTurnAction)			{if IsTurn16()}
	-- 1x	Turn17Landing(StartTurnAction)		{if IsTurn17()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{2,18}},	-- supply depot NW of Perwez, per scenario
	eqs = {{"CharB1",10}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=19, traits={UnitTrait.CripplingBlow, UnitTrait.FastRetreat}}, 	-- tank in column NW of Perwez, per scenario
	{unit_id=41, traits={UnitTrait.DoubleAttack, UnitTrait.FastRetreat}},	-- tank in column NW of Perwez, per scenario
	{unit_id=47, traits={UnitTrait.Prudent, UnitTrait.FastRetreat}},		-- rcn  SW of Gembloux, per scenario
	{unit_id=52, traits={UnitTrait.FierceFighter}}							-- ftr  SW of Gembloux, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_heroes)	-- French units
end

---------------------------
-- Objective 1: Raid Huy --
---------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Hannut","earned_cp_format","Bonus Objective to Raid Huy completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

------------------------------------------
-- Objective 2: Destroy 20 French Units --
------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Hannut","earned_cp_format2","Bonus Objective to Destroy 20 French Units completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Hannut","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 4,
	units= {{"Neubaufahrzeug","",0,0}},
	zone = {{23,6},{24,6},{25,6},{26,6},{23,7},{24,7},{25,7},{24,8},{25,8},{24,9}}
}
uniquetank = false

-- ** Condition for OnTurn16() **
function IsTurn16()
	return world.round == 16
end

-- ** Effect(StartTurnAction) {if IsTurn16()} **
function OnTurn16()
	if (campaign.comm_points < trade.cps) then return end
	-- skip if already have it:
	for _,u in pairs(world.units) do	-- for all units
		if (u.owner_id == 0) then	-- that belong to player
			if (u.type.name == "Neubaufahrzeug") then return end
		end
	end

	local message = string.format(tostring(NSLOCTEXT("scenario_Hannut","difficult_choice","Mein General, excuse the interruption, but I believe there is a matter of some interest that deserves your attention.  It seems that some prototype multi-turret tanks were deployed in the ongoing campaign in Norway, but their performance seems to have been rather disappointing.  Despite possessing considerable firepower, the tanks were found to be too vulnerable to enemy fire.\n\nI bring this to your attention, because the vehicles are apparently on their way to the scrapyard.  If you would prefer to get these Neubaufahrzeug transferred to your command instead, I am certain this can be arranged.  It will be too late for them to assist in this battle, but we will have them to keep for future actions.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 4 Commendation Points for this unique unit?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Hannut","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Hannut","option1_tooltip","The unit will be ready on turn 17")
		},
		{
			title  = NSLOCTEXT("scenario_Hannut","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Hannut","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		uniquetank = true	-- set
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Hannut","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Hannut","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-- ** Condition for Turn17Landing() **
function IsTurn17()
	return world.round == 17
end

-- ** Effect(StartTurnAction) {if IsTurn17()} **
function Turn17Landing(action)
	if (uniquetank == true) then
		TutorialMessage(NSLOCTEXT("scenario_Hannut","string_2","The Neubaufahrzeug unique tank has arrived near Oreye."))
		lib.SpawnWave(0, trade.zone, trade.units)	-- create & place player unit
	end
end
