-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Germany - 1st Panzer
p_1div = 1
	-- 2 [AI]:	Germany - 7th Panzer
p_7div = 2
	-- 3 [AI]:	France
p_FR = 3

-- 2 Objectives defined in scenario:
	-- 0 		Custom objective		CustomSuccess() | CustomFail()
	-- 1 opt	Capture 2 victory hexes	(16;41)(15;43)

-- 7 Triggers defined in scenario:
	-- 1x	NemesisHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)		{if Objective1Status()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)
	-- 		OnCaptureStoreHouse2(CaptureFlagAction)
	-- 		OnCaptureStoreHouse3(CaptureFlagAction)
	-- 1x	Effect2(DeathAction|SurrenderAction)	{if Condition2()}
	-- 1x	EncounterAction(MoveAction)				{if EncounterCheck()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

caches = {
	{	-- 1:
		loc = {{31,43}},	-- village in SE corner, per scenario
		eqs = {{"CharB1",5}}
	},
	{	-- 2:
		loc = {{16,8}},		-- Dinant, per scenario
		eqs = {{"AMC35",25},{"HotchkissH35",15},{"Panhard178",15}}
	},
	{	-- 3:
		loc = {{17,25}},	-- airfield with 2 grounded aircraft, per scenario
		eqs = {{"Breguet693",30}}
	}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

---------------------
-- Equipment cache --
---------------------

-- @TODO: collapse these (since all 3 get called upon any flag capture but have mutually exclusive locations), by
-- parameterizing the cache location and equipment table

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(caches[1].loc, action.flag)) then
		lib.AddEquipments(0, caches[1].eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Sedan","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse2(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(caches[2].loc, action.flag)) then
		lib.AddEquipments(0, caches[2].eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Sedan","string_C2","<bi>Hauptmann Wagner: </>Mein General, this is most bizarre.  Dinant is a ghost town, and a host of abandoned French vehicles are scattered everywhere.  We've commandeered them all and you can access them as captured equipment."))
	end
end

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse3(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(caches[3].loc, action.flag)) then
		lib.AddEquipments(0, caches[3].eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Sedan","string_C3","<bi>Hauptmann Wagner: </>Mein General, our ground forces report the destruction of a squadron of French bombers preparing to take off.  In securing the area, they also discovered some idle bombers hidden near the treeline.  We've commandeered them and you can access them as captured equipment."))
	end
end

-------------
-- Nemesis --
-------------

nem_unit = 102	-- de Gaulle is unit ID #102, per scenario

enemy_nemesis = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.NoRetreat}, portrait = "/Game/Gui/Common/Heroes/fr_in_degaulle.fr_in_degaulle"}	-- tank "Charles de Gaulle" (Nemesis) NE Tours-en-Vimeu, per scenario
}

-- ** 1x Effect(NewRoundAction) **
function NemesisHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_nemesis)	-- de Gaulle
end

-- ** Condition for Effect2() **
function Condition2()
	return world:GetUnit(nem_unit) == nil	-- Nemesis eliminated
end

-- ** 1x Effect(DeathAction|SurrenderAction) {if Condition2()} **
function Effect2()
	--  see: AO1940/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then campaign.nemesislives = false end
	TutorialMessage(NSLOCTEXT("scenario_Sedan","string_death","<bi>Hauptmann Wagner: </>That was one stubborn Frenchman.  I certainly hope that is the last we will see of him."))
end

-----------------------------------------------------------------------------------------------------------------------------------------------------
-- Objective 0: Make Contact with 7th Panzer Division.  Making contact requires moving a ground unit within 2 hexes of a 7th Panzer Division vehicle. --
-----------------------------------------------------------------------------------------------------------------------------------------------------

-- ** Condition for Objective 0 success **
function CustomSuccess()
	local filter1 =		-- ground units of player
	{
		player = 0,
		ground = true
	}
	local filter2 =
	{
		player = p_7div,
		id = {0,1,99},	-- unit IDs of 7th Panzer Division
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** Condition for Objective 0 failure **
function CustomFail(action)
	return action:GetActionClass() == "TurnsLimitAction"
end

--------------------------------
-- Objective 1: Capture Sedan --
--------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Sedan","earned_cp_format","Bonus Objective to Capture Sedan completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

------------------------
-- Messages to player --
------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =	-- any units of player
	{
		player = 0,
	}
	local filter2 =
	{
		player = p_1div,
		id = {2,3,4,5,6,7,8,9,101,113}, -- unit IDs of 1st Panzer Division
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_Sedan","string_sedan","<bi>Hauptmann Wagner: </>Mein General, our troops have made contact with friendly forces.  They aren't the 7th Panzer we are looking for, but rather elements of 1st Panzer Division.  They're fighting hard for control of Sedan against French counterattack, and would welcome our assistance."))
end
