-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Germany - 7th Panzer
p_7div=1
	-- 2 [AI]:	UK - BEF
p_UK=2

-- 3 Objectives defined in scenario:
	-- 0 		Guard 8 units			unit IDs 6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Capture 2 victory hexes	(13;8)(15;8)

-- 8 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}
	-- 1x	FrenchCheck(StartTurnAction)		{if IsFirstTurn()}
	-- 1x	Turn2(StartTurnAction)				{if IsSecondTurn()}
	-- 1x	PrestigeSink(NewRoundAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{15,3}},	-- Matilda depot, per scenario
	eqs = {{"MatildaI",15},{"MatildaII",10}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{7,2},{5,3},{6,3},{4,4},{5,4},{6,4},{7,4},{3,5},{4,5},{5,5},{6,5},{3,6},{4,6},{5,6},{2,7},{3,7},{4,7}}	-- SW
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 1, traits={UnitTrait.CripplingBlow}},								-- tank "Sergeant Armit" SE of Basseux, per scenario
	{unit_id=25, traits={UnitTrait.AggressiveCounterattack}},					-- tank "Sergeant Reed" NW of Wancourt, per scenario
	{unit_id=90, traits={UnitTrait.FearsomeReputation, UnitTrait.FastRetreat}},	-- tank "Major Fernie" in camp NW of Gavrelle, per scenario
	{unit_id=99, traits={UnitTrait.AimingAssistance, UnitTrait.Provocator, UnitTrait.FastRetreat}} 	-- tank "Lt. Colonel Heyland" in camp NW of Haute-Avesnes, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_UK, enemy_heroes)	-- UK units
end

-------------------
-- Prestige dump --
-------------------

frenchcol = true	-- flag for extra French Colonial troops

-- ** 1x Effect(NewRoundAction) **
function PrestigeSink()
	local message = string.format(tostring(NSLOCTEXT("scenario_Arras","difficult_choice","Mein General, we have a problem.  In fact, it is the same problem Rommel already ran into at Dinant: We have advanced so far, so fast, and taken so many prisoners, our operations are in danger of being slowed down under the sheer weight of prisoner management!  This latest group of French Colonial Troop captures is the straw that has broken our back.  Something must be done.\n\nIf we just let them go, it will certainly take the strain off of our supply situation.  But these are no mere civilians, just letting them go runs a serious risk they will return to French lines and re-arm to fight us once again.  On the other hand, locking them all down will really eat into our available manpower and supplies.  I estimate it will cost us half of our stockpile.  But a decision to properly detain and later turn over our captive POWs will also garner some political favor with the OGE, whose administration will eventually catch up to us no matter how fast our advance.\n\nYou have %d Commendation Points.\n\nWill you exchange HALF of your total prestige for 7 Commendation Points or risk fighting additional enemies?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Arras","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Arras","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Arras","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Arras","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 7
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		frenchcol = false
		local p = world:GetPlayer(player)
		p.prestige = math.ceil(p.prestige / 2)  -- remove 50% of prestige
	end

	local choice_made =
	{
		NSLOCTEXT("scenario_Arras","choice_made1","You choose to lock all captives down, costing half of your existing supplies.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Arras","choice_made2","You choose to free your captives.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-- ** Condition for FrenchCheck() **
function IsFirstTurn()
	return world.round == 1
end

-- ** Effect(StartTurnAction) {if IsFirstTurn()} **
function FrenchCheck()
	if (frenchcol == false) then	-- kill off the French Colonial units
		local french_ids = {110,111,112,113,114}	-- unit ID #s, per scenario
		for _,french_id in ipairs(french_ids) do
			world:Exec(world:MakeDeathAction(world:GetUnit(french_id)))
		end
	end
end

------------------------
-- Messages to player --
------------------------

-- ** Condition for Turn2() **
function IsSecondTurn()
	return world.round == 2
end

-- ** Effect(StartTurnAction) {if IsSecondTurn()} **
function Turn2()
	TutorialMessage(NSLOCTEXT("scenario_Arras","string_over","<bi>Hauptmann Wagner: </>Those light AT gun pickets got completely overrun.  I sure hope we have something heavier than Pak 36 anti-tank guns!"))
end

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Arras","earned_cp_format","Bonus Objective to Capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------------------------
-- Objective 2: Capture Arras Bridges --
----------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Arras","earned_cp_format2","Bonus Objective to Capture Arras Bridges completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Arras","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden British tank repair depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {7,11,15,17}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"GBInfantry","",0,900},{"GBInfantry","Lorry",0,900},{"MatildaII","",0,900},{"MatildaI","",0,900},{"QF25pdrATY","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900},{"HurricaneMkI","",1,900}},
	{{"GBInfantry","",0,900},{"GBInfantry","Lorry",0,900},{"MatildaII","",0,900},{"MatildaI","",0,900},{"QF25pdrATY","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900},{"HurricaneMkI","",1,900}},
	{{"VickersMkVI","",0,900},{"CruiserMkIV","",0,900},{"HumberACMkI","",0,900},{"CruiserMkIV","",0,900},{"BL5-5inch","Lorry",0,900},{"QF2pounder","Lorry",0,900},{"HurricaneMkI","",1,900}},
	{{"CruiserMkI","",0,900},{"GBHWInf","Lorry",0,900},{"Wasp","",0,900},{"MatildaI","",0,900},{"BL5-5inch","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900},{"BattleMkII","",1,900}},
	{{"CruiserMkI","",0,900},{"GBEngineers","Lorry",0,900},{"MatildaII","",0,900},{"DaimlerDingo","",0,900},{"BL6inch26cwt","Lorry",0,900},{"QF2pounder","Lorry",0,900},{"SpitfireMkI","",0,0}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_UK, zones[math.random(#zones)], waves[math.random(#waves)])
end
