-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Germany - 7th Panzer
p_7div=1
	-- 2 [AI]:	France
p_FR=2

-- 2 Objectives defined in scenario:
	-- 0 		Capture 2 victory hexes	(15;16)(16;17)
	-- 1 opt	Capture 8 victory hexes	(22;4)(11;13)(17;13)(10;15)(10;16)(10;18)(24;19)(15;21)

-- 3 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{23,3}},	-- D20 depot, per scenario
	eqs = {{"D520",35}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 22, traits={UnitTrait.NoSupply}},		-- inf alp in Lille, per scenario
	{unit_id=118, traits={UnitTrait.Resilient}},	-- ftr W of Lille, per scenario
	{unit_id= 82, traits={UnitTrait.FearsomeReputation, UnitTrait.AimingAssistance}},	-- tank SE Lille, per scenario
	{unit_id= 91, traits={UnitTrait.ATSupport, UnitTrait.TankKiller, UnitTrait.FastEntrenchment}}	-- tank NW of Lille, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_heroes)	-- French units
end

---------------------------------------------------------------
-- Objective 1: Capture all other Victory Hexes before Lille --
---------------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Lille","earned_cp_format","Bonus Objective to Capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Lille","string_C","<bi>Hauptmann Wagner: </>Mein General, some of our forces have found a hidden French aircraft depot.  We've commandeered the contents and you can access them as captured equipment."))
	end
end
