-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	UK - BEF
p_UK=1

-- 5 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex	(16;14)
	-- 1 opt	Destroy 5 units		unit IDs 5,47,48,49,50,51,52
	-- 2 opt	Destroy 5 units		unit IDs 7,42,43,44,45,46
	-- 3 opt	Destroy 10 units	unit IDs 6,8,9,10,11,12,13,14,15,16,17,18,19,20,21,53
	-- 4 opt	Destroy 9 units		unit IDs 56,57,60,61,62,64,65,66,67,70,74,75,76,77

-- 6 Triggers defined in scenario:
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}
	-- 1x	OnObjective3(ObjectiveStatusAction)	{if Objective3Status()}
	-- 1x	OnObjective4(ObjectiveStatusAction)	{if Objective4Status()}
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}
	-- 1x	Bar(NewRoundAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{1,1},{2,1},{3,1},{4,1},{5,1},{6,1},{7,1},{1,2},{2,2},{3,2},{4,2},{5,2},{6,2}}	-- SW
}

--------------
-- Triggers --
--------------

---------------------
-- Player Hero(es) --
---------------------

-- ** 1x Effect(NewRoundAction) **
function Bar()
	if (campaign.comm_points < 7) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Dunkirk","difficult_choice","Mein General, I have another officer to bring to your attention.  Heinz has been with us since the French Saar Offensive where he earned an Iron Cross, and despite his insubordinate inclinations, I have been convinced that he has some very real potential as a fighter pilot and commander.\n\nAs with any potentially troublesome candidate, it will take quite a bit of your influence to push his promotion through.  If you ask me, I think any political price is worth the potential reward, but the decision is yours.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 7 Commendation Points for this unique officer?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Dunkirk","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Dunkirk","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Dunkirk","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Dunkirk","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = -7
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		CreateBar()
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Dunkirk","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Dunkirk","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

bar_hero = {
	{
		name=NSLOCTEXT("scenario_Dunkirk","Heinrich_Bar","Heinrich Bar"),
		portrait="/Game/Gui/Common/Heroes/de_af_baer.de_af_baer",
		traits={UnitTrait.Famous,UnitTrait.DoubleAttack},
--		modifiers={{type=Initiative,mod=3},{type=Spotting,mod=1},{type=Speed,mod=10}},
		attack_modifiers={{type = TargetType.Air,mod=1}},	--,{type=TargetType.Soft,mod=5}},
		unit_classes={UnitClass.Fighter}	--, UnitClass.TacticalBomber}
	}
}

function CreateBar()
	lib.CreateAndAssignHeroes(0,bar_hero)
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {2,4,6,8,10}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"SpitfireMkI","",0,0}},
	{{"SpitfireMkI","",0,0},{"SpitfireMkI","",0,0}},
	{{"SpitfireMkI","",0,0},{"SpitfireMkI","",0,0},{"SpitfireMkI","",0,0}},
	{{"SpitfireMkI","",0,0},{"SpitfireMkI","",0,0}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_UK, zones[math.random(#zones)], waves[math.random(#waves)])
end

------------------------------------------
-- Objective 1: Sink 5 Naval Transports --
------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Dunkirk","earned_cp_format","Bonus Objective to sink 5 Naval Transports completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

--------------------------------------
-- Objective 2: Sink 5 Patrol Boats --
--------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Dunkirk","earned_cp_format2","Bonus Objective to sink 5 Patrol Boats completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------------------------
-- Objective 3: Destroy 10 Air Defense Units --
-----------------------------------------------

-- ** Condition for OnObjective3() **
function Objective3Condition(action)
	return action.side == 0 and action.objective == 3 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective3Condition()} **
function OnObjective3(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Dunkirk","earned_cp_format3","Bonus Objective to destroy 10 Air Defense Units completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------------
-- Objective 4: Destroy 9 Trucks --
-----------------------------------

-- ** Condition for OnObjective4() **
function Objective4Condition(action)
	return action.side == 0 and action.objective == 4 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective4Condition()} **
function OnObjective4(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Dunkirk","earned_cp_format4","Bonus Objective to destroy 9 Trucks completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
