-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Germany - 7th Panzer
p_7div = 1
	-- 2 [AI]:	France
p_FR = 2
	-- 3 [AI]:	UK - BEF
p_UK = 3

-- 2 Objectives defined in scenario:
	-- 0 @end	Capture 4 victory hexes		(10;4)(24;6)(13;7)(8;10)(16;10)(21;11)(22;14)(17;15)(12;16)(27;18)(22;20)(27;23)
	-- 1 opt	Capture 12 victory hexes	(10;4)(24;6)(13;7)(8;10)(16;10)(21;11)(22;14)(17;15)(12;16)(27;18)(22;20)(27;23)

-- 4 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}
	-- 1x	EncounterAction(MoveAction)			{if EncounterCheck()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.

-- There can be any number of zones in this list, the game will pick a random one every time
FR_zones = {
	{{1,6},{1,7},{2,8},{2,9},{3,10},{3,11},{3,12},{2,13},{2,14},{1,15},{1,16}},		-- NW
	{{1,21},{2,21},{3,21},{4,22},{4,23},{5,24},{4,25},{4,26},{3,27},{3,28},{2,29}},	-- SW
	{{25,30},{26,30},{28,30},{29,30},{30,30},{31,30},{23,31},{20,32},{22,32}}		-- SE
}

UK_zones = {
	{{8,29},{10,29},{7,30},{6,31},{11,31},{6,32},{8,32},{9,32},{10,32},{13,32}}
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 25, traits={UnitTrait.LowProfile, UnitTrait.FastRetreat}},	-- tank "4th Armored Division" E Tours-en-Vimeu, per scenario
	{unit_id=111, traits={UnitTrait.CheapReplacements}},					-- bmr in SW camp, per scenario
	{unit_id= 96, traits={UnitTrait.CityFighter, UnitTrait.MachineGun}} 	-- inf eng SW of Liercourt, per scenario
}

UK_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 98, traits={UnitTrait.Avenger, UnitTrait.FastRetreat}}		-- UK tank in S camp, per scenario
}

-------------
-- Nemesis --
-------------

nem_unit=23	-- de Gaulle is unit ID #23, per scenario

enemy_nemesis = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.NoRetreat}, portrait = "/Game/Gui/Common/Heroes/fr_in_degaulle.fr_in_degaulle"}	-- tank "Charles de Gaulle" (Nemesis) NE Tours-en-Vimeu, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_FR, enemy_heroes)	-- French units
	lib.CreateAndAssignHeroes(p_UK, UK_heroes)		-- UK unit
--  see: AO1940/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then
		lib.CreateAndAssignHeroes(p_FR, enemy_nemesis)	-- de Gaulle
	else
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis unit eliminated previously, remove from scenario
	end
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {3,6,9,10,12,15,18,21}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
FR_waves = {
	{{"FRInfantry","HorseTransport",0,900},{"SomuaS35","",0,900},{"FRCavalry","",0,900},{"AMC35","",0,900},{"RenaultR35","",0,900},{"HotchkissH35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"MS406","",0,900},{"Breguet693","",0,900}},
	{{"HotchkissH35","",0,900},{"FREngineers","HorseTransport",0,900},{"FR75mmmle1897","HorseTransport",0,900},{"FR105mmmle1913","HorseTransport",0,900},{"Panhard178","",0,900},{"25mmSA34","HorseTransport",0,900},{"FR37mmmle30AA","HorseTransport",0,900}},
	{{"CharB1","",0,900},{"FRInfantry","",0,900},{"FR75mmmle1897","HorseTransport",0,900},{"FR105mmmle1913","HorseTransport",0,900},{"Panhard178","",0,900},{"25mmSA34","HorseTransport",0,900},{"FR37mmmle30AA","HorseTransport",0,900}},
	{{"SomuaS35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"Panhard178","",0,900},{"FRInfantry","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"FREngineers","HorseTransport",0,900},{"D520","",1,900},{"Breguet693","",0,900}},
	{{"FT17","",0,900},{"FT17","",0,900},{"AMC35","",0,900},{"RenaultR35","",0,900},{"HotchkissH35","",0,900},{"SomuaS35","",0,900},{"CharB1","",0,900},{"MS406","",0,900},{"Breguet693","",0,900}}
}

UK_waves = {
	{{"GBInfantry","",0,900},{"GBInfantry","Lorry",0,900},{"MatildaII","",0,900},{"CruiserMkI","",0,900},{"QF25pdrATY","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900}},
	{{"GBInfantry","",0,900},{"GBInfantry","Lorry",0,900},{"MatildaII","",0,900},{"CruiserMkI","",0,900},{"QF25pdrATY","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900}},
	{{"VickersMkVI","",0,900},{"CruiserMkIV","",0,900},{"HumberACMkI","",0,900},{"CruiserMkIV","",0,900},{"BL5-5inch","Lorry",0,900},{"QF2pounder","Lorry",0,900}},
	{{"CruiserMkI","",0,900},{"GBHWInf","Lorry",0,900},{"Wasp","",0,900},{"MatildaI","",0,900},{"BL5-5inch","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900}},
	{{"CruiserMkI","",0,900},{"GBEngineers","Lorry",0,900},{"MatildaII","",0,900},{"DaimlerDingo","",0,900},{"BL6inch26cwt","Lorry",0,900},{"QF2pounder","Lorry",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

-- @TODO: Nemesis eliminated
	-- added here until better hook established (scenario change):
	if (world:GetUnit(nem_unit) == nil and campaign.nemesislives == true) then campaign.nemesislives = false end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	-- Determine the player to get the next wave:
	local player = p_FR
	local randoplayer = math.random(p_FR,5)	-- With extra chance (4/5) to be French
	if (randoplayer < 5) then player = p_FR else player = p_UK end

	-- Determine the right zone and units to spawn
	local zone
	local units
	if (player == p_FR) then
		zone = FR_zones[math.random(#FR_zones)]
		units= FR_waves[math.random(#FR_waves)]
		if (zone == FR_zone[1]) then	-- NW
			TutorialMessage(NSLOCTEXT("scenario_Abbeville","string_Ro","<bi>General Rommel: </>French reinforcements have been spotted in the Northwestern sector, support requested."))
		end
	else	-- p_UK
		zone = UK_zones[math.random(#UK_zones)]
		units= UK_waves[math.random(#UK_waves)]
	end
	lib.SpawnWave(player, zone, units)
end

--------------------------------------------------------------------------
-- Objective 1: Control all 12 Victory Hexes at the end of the scenario --
--------------------------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Abbeville","earned_cp_format","Bonus Objective to hold all Victory Hexes at the end of the scenario completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------------
-- Proximity/Encounter detection --
-----------------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =
	{
		player = 0,
	}
	local filter2 =
	{
		player = p_FR,
		id = {17,nem_unit,25,26,27,28,29,30,31,33,34,35}, -- unit IDs of Fr. 4th Armored Division
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
		TutorialMessage(NSLOCTEXT("scenario_Abbeville","string_degaulle","<bi>Hauptmann Wagner: </>A warning just came in from the frontline: some of our forces have confirmed visual contact with an elite French armored detachment on the field.  If the radio intercepts are to be believed, it's being led by that stubborn Frenchman we encountered near Sedan.\n\nIt definitely appears that this Commander de Gaulle is made of sterner stuff.  Better get the 88s ready, mein Herr."))
end
