-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	UK
p_UK=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture all victory hexes
	-- 1 opt	Capture 1 victory hex	(5;3)
	-- 2 opt	Destroy 6 units		unit IDs 27,28,29,30,31,32 (radars)

-- 4 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

-------------------
-- Prestige dump --
-------------------

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	local message = string.format(tostring(NSLOCTEXT("scenario_Dover","difficult_choice2","Herr General, as part of the preparation for Operation Sea Lion, I have a special proposal to offer your command.  As shipping your invasion force, and all of the supplies they will need in the upcoming campaign, across the English Channel presents an unusual logistical challenge, I believe a compromise is required.\n\nTo make sure there is enough of everything, we need to set your supplies to a fixed amount.  As partial compensation, a dedicated detachment of salvage haulers will be made available to join the invasion.\n\nYou have %d Commendation Points.\n\nWould you like to reset your prestige to 8500 and gain 9 Commendation Points?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Dover","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Dover","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Dover","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Dover","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 9
		campaign.comm_points = lib.UpdateCommendationPoints(comm)

		local p = world:GetPlayer(player)
		p.prestige = 8500 -- prestige reset
		-- p.prestige = p.prestige * 70 / 100 -- remove 30% of prestige
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Dover","choice_made1","You accept the offer and fixed resource amount with it.  You now have exactly 8500 prestige and %d Commendation Points."),
		NSLOCTEXT("scenario_Dover","choice_made2","You choose to reject the offer.  You still have %d Commendation Points."),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=57, traits={UnitTrait.Evasive}},			-- ftr bmr "54th Squadron" NW of Lydd, per scenario
	{unit_id=72, traits={UnitTrait.Avenger}},			-- ftr bmr "234th Squadron" N of Dover, per scenario
	{unit_id=73, traits={UnitTrait.IgnoreMassAttack}},	-- ftr bmr "245th Squadron" Canterbury, per scenario
	{unit_id=66, traits={UnitTrait.PreciseOptics}} 		-- tank WSW of Ashford, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(1, enemy_heroes)
end

---------------------------------------------------------------------
-- Objective 1: Raid Ashford before capturing the last Victory Hex --
---------------------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Dover","earned_cp_format","Bonus Objective to Raid Ashford completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

------------------------------------------------
-- Objective 2: Destroy 6 Radar Installations --
------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Dover","earned_cp_format2","Bonus Objective to Destroy Radar Installations completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
