-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	UK
p_UK=1

-- 3 Objectives defined in scenario:
	-- 0 		Capture all victory hexes
	-- 1 opt	Capture 1 victory hex	(16;4) Royal Tunbridge Wells
	-- 2 opt	Capture 1 victory hex	(5;18) Brighton

-- 8 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}
	-- 1x	BCheck(NewRoundAction)
	-- 1x	Effect2(StartTurnAction)			{if BTimer()}
	-- 1x	EncounterAction(MoveAction)			{if EncounterCheck()}
	-- 1x	DGEncounterAction(MoveAction)		{if DGEncounterCheck()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=83, traits={UnitTrait.IgnoresZOC}}	-- tank N Royal Tunbridge Wells, per scenario
}

-------------
-- Nemesis --
-------------

nem_unit=72	-- de Gaulle is unit ID #72, per scenario

-- @TODO:
-- Nemesis eliminated

enemy_nemesis = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.NoRetreat}, portrait = "/Game/Gui/Common/Heroes/fr_in_degaulle.fr_in_degaulle"}	-- tank "Charles de Gaulle" (Nemesis) WNW Royal Tunbridge Wells, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_UK, enemy_heroes)
--  see: AO1940/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then
		lib.CreateAndAssignHeroes(p_UK, enemy_nemesis)	-- de Gaulle
	else
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis unit eliminated previously, remove from scenario
	end
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 7,
	eqs = {{"SpitfireMkII",31}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Brighton","difficult_choice2","In the immediate aftermath of our invasion, our forces overran several enemy airfields.  Although the retreating British tried to sabotage them before our arrival, it is clear that they ran out of time and could not destroy everything of value.  In total, we inventoried several squadrons worth of Spitfire aircraft that we could repair and field.  Major Galland was positively frothing at the mouth when he heard the news, and I could only placate the man by assuring him I would bring this to your immediate attention.\n\nAssigning this additional task to our special recovery teams will take some influence, but I must insist we put them on it right away.  Otherwise, I do not think Major Galland will ever speak to me again if we neglected this opportunity that he has been waiting so long to have.\n\nYou have %d Commendation Points.\n\nWould you like to use 7 Commendation Points acquire a collection of Spitfire aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Brighton","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Brighton","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Brighton","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Brighton","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Brighton","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Brighton","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

------------------------------------------------------------------------------------
-- Objective 1: Raid Royal Tunbridge Wells before capturing the last Victory Hex. --
------------------------------------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Brighton","earned_cp_format","Bonus Objective to Raid Royal Tunbridge Wells completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))

-- @TODO: Nemesis eliminated
	-- added here until better hook established (scenario change):
	if (world:GetUnit(nem_unit) == nil and campaign.nemesislives == true) then campaign.nemesislives = false end
end

-----------------------------------------------------------------------
-- Objective 2: Raid Brighton before capturing the last Victory Hex. --
-----------------------------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Brighton","earned_cp_format2","Bonus Objective to Raid Brighton completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))

-- @TODO: Nemesis eliminated
	-- added here until better hook established (scenario change):
	if (world:GetUnit(nem_unit) == nil and campaign.nemesislives == true) then campaign.nemesislives = false end
end

-----------------------------------
-- Proximity/Encounter detection --
-----------------------------------

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
-- ** Condition for EncounterAction() **
function NavalEncounterCheck()
	local filter1 =
	{
		player = 0,
		naval = true,
		air = true
	}
	local filter2 =
	{
		player = p_UK,
		naval=true
	}
	return lib.ProximityCheck(filter1, filter2, 4)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_Brighton","string_fleet","<bi>KRIEGSMARINE COMMUNIQUE: </>\n\n\nBattleship Bismarck has made contact with the enemy.\nRoyal Navy battlegroup possesses extreme numerical superiority.\nWe will fight them to our last; to victory or till death!\n\n-Admiral Lutjens"))

-- @TODO: Nemesis eliminated
	-- added here until better hook established (scenario change):
	if (world:GetUnit(nem_unit) == nil and campaign.nemesislives == true) then campaign.nemesislives = false end
end

-- ** Condition for DGEncounterAction() **
function DGEncounterCheck()
	local filter1 =
	{
		player = 0,		-- filter units of player 0
		ground = true	-- filter only ground units
	}
	local filter2 =
	{
		id = {nem_unit},		-- Nemesis unit ID
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 3)
end

-- ** 1x Effect(MoveAction) {if DGEncounterCheck()} **
function DGEncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_Brighton","string_gaulle","<bi>Field Marshal Habermann: </>Herr General, you're not going to believe this, but radio intercepts have confirmed contact with a British unit being led by none other than de Gaulle himself.  I had heard of your duels with him in France, and it would seem he still refuses to give up the fight!\n\nYou had best be on your guard, such a tenacious enemy deserves a healthy amount of respect and caution when engaging."))
end

-----------------
-- KMS Blcher --
-----------------

-- ** Condition for Effect2() **
function BTimer()
	return world.round == 1
end

-- ** Effect(StartTurnAction) {if BTimer()} **
function Effect2()
	-- see: AO1940/script.lua for initial definition of campaign.blucher
	if (campaign.blucher == true) then
		TutorialMessage(NSLOCTEXT("scenario_Brighton","string_blu","<bi>KRIEGSMARINE COMMUNIQUE: </>\n\n\nHeavy Cruiser Blucher has arrived.\nShip and crew ready to join the fleet."))
	end
end

-- ** 1x Effect(NewRoundAction) **
function BCheck()
	if (campaign.blucher == false) then	-- didn't survive Fornebu, remove from scenario:
		world:Exec(world:MakeDeathAction(world:GetUnit(101))) -- KMS Blcher is unit ID #101, per scenario
	end
end
