-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	UK
p_UK=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 5 victory hexes	(25;7)(16;10)(8;14)(5;18)(23;21)(13;22)(5;32)(26;36)(13;37)
	-- 1 opt	Capture 1 victory hex	(15;5) -- S London
	-- 2 opt	Capture 5 victory hexes	(7;13)(2;15)(29;17)(27;18)(13;21) -- fortifications

-- 6 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{5,2}},	-- Great West Aerodrome, per scenario (Meteor jet parts)
	eqs = {{"MeteorMkIII",1}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{1,5},{2,6},{2,7},{3,8},{2,9},{3,9},{2,10},{3,10},{4,10},{1,11}},
	{{29,2},{29,3},{29,4},{28,5},{29,5},{28,6},{29,6},{30,6},{28,7},{29,7},{29,8},{29,9},{30,10},{30,11},{31,12}}
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=10, traits={UnitTrait.ArtySupport}},			-- inf (Aus.) in 2nd fort NE Seven Oaks, per scenario
	{unit_id=16, traits={UnitTrait.Provocator}},			-- tank SW Redhill, per scenario
	{unit_id=38, traits={UnitTrait.EntrenchmentSupport}},	-- art "Colonel McNeil" in Epsom, per scenario
	{unit_id=43, traits={UnitTrait.Camouflage}},			-- at SE Epsom, per scenario
	{unit_id=96, traits={UnitTrait.MachineGun}} 			-- ftr bmr "303rd Squadron" (Pol.) London, per scenario
}

-------------
-- Nemesis --
-------------

nem_unit=0	-- de Gaulle is unit ID #0 "Charles de Gaulle", per scenario

enemy_nemesis = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=nem_unit, traits={UnitTrait.NoRetreat, UnitTrait.IncMaxOverstrength}, portrait = "/Game/Gui/Common/Heroes/fr_in_degaulle.fr_in_degaulle"}	-- tank "Charles de Gaulle" (Nemesis) London, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_UK, enemy_heroes)
--  see: AO1940/script.lua for initial definition of campaign.nemesislives
	if (campaign.nemesislives == true) then
		lib.CreateAndAssignHeroes(p_UK, enemy_nemesis)	-- de Gaulle
	else
		world:Exec(world:MakeDeathAction(world:GetUnit(nem_unit)))	-- Nemesis unit eliminated previously, remove from scenario
	end
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 8,
	eqs = {{"MatildaII",35}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Epsom","difficult_choice2","There is a special report from our repair teams for your attention.  After the last skirmish with the British, they have been working to exhaustion to keep our equipment in working order.  Even so, there are still lots of damaged and abandoned British Matilda II tanks that continue to litter the battlefield.\n\nIf you want to use some of your influence to push our crews just a little bit harder, I am certain we can reclaim more than a few of these vehicles for our own use.\n\nYou have %d Commendation Points.\n\nWould you like to use 8 Commendation Points acquire extra Matilda II tank salvage?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Epsom","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Epsom","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Epsom","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Epsom","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Epsom","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Epsom","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-------------------------------------------
-- Objective 1: Raid Outskirts of London --
-------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Epsom","earned_cp_format","Bonus Objective to Raid Outskirts of London completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-------------------------------------------
-- Objective 2: Capture 5 Fortifications --
-------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Epsom","earned_cp_format2","Bonus Objective to Capture 5 Fortifications completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {2,3,6,9,10,12,15,18,21,25}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"GBInfantry","",0,900},{"GBInfantry","Lorry",0,900},{"MatildaII","",0,900},{"CruiserMkI","",0,900},{"QF25pdrATY","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900},{"HurricaneMkI","",0,900}},
	{{"GBInfantry","",0,900},{"GBInfantry","Lorry",0,900},{"MatildaII","",0,900},{"CruiserMkI","",0,900},{"QF25pdrATY","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900},{"HurricaneMkI","",0,900}},
	{{"VickersMkVI","",0,900},{"CruiserMkIV","",0,900},{"HumberACMkI","",0,900},{"CruiserMkIV","",0,900},{"BL5-5inch","Lorry",0,900},{"QF2pounder","Lorry",0,900},{"HurricaneMkI","",0,900}},
	{{"CruiserMkI","",0,900},{"GBHWInf","Lorry",0,900},{"Wasp","",0,900},{"MatildaI","",0,900},{"BL5-5inch","Lorry",0,900},{"40mmBoforsAA","Lorry",0,900},{"SpitfireMkI","",0,900}},
	{{"CruiserMkI","",0,900},{"GBEngineers","Lorry",0,900},{"MatildaII","",0,900},{"DaimlerDingo","",0,900},{"BL6inch26cwt","Lorry",0,900},{"QF2pounder","Lorry",0,900},{"SpitfireMkI","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

-- @TODO: Nemesis eliminated
	-- added here until better hook established (scenario change):
	if (world:GetUnit(nem_unit) == nil and campaign.nemesislives == true) then campaign.nemesislives = false end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_UK, zones[math.random(#zones)], waves[math.random(#waves)])
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Epsom","string_sco1","Report coming in from the unit that just took control of the Great West Aerodrome.  In addition to securing a huge supply cache, they say they have found some extremely bizarre aircraft blueprints.  Now is no time for looking at blueprints, so I told them to just grab whatever they could get their hands on."))
		TutorialMessage(NSLOCTEXT("scenario_Epsom","string_sco2","Perhaps after we return to Germany we can find someone who can make sense or use of these captured technical documents."), false)
	end
end
