-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	UK, NZ
p_UK=1
p_NZ=p_UK

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 3 victory hexes	(14;22)(12;23)(15;23) -- Portsmouth
	-- 1 opt	Capture 1 victory hex	(2;13)	-- Southampton
	-- 2 opt	Destroy 7 units			unit IDs 6,9,10,11,12,16,18

-- 4 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(ObjectiveStatusAction)	{if Objective1Status()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Status()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=46, traits={UnitTrait.NoSupply}},				-- inf eng in Portsmouth, per scenario
	{unit_id=51, traits={UnitTrait.StrikesFirst}},			-- inf (NZ) S of Singleton, per scenario
	{unit_id=62, traits={UnitTrait.OverwhelmingAttack}}		-- tank E of Winchester zone, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_UK, enemy_heroes)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 9,
	eqs = {{"MatildaII",19},{"HurricaneMkIIC",17},{"SpitfireMkII",21},{"BeaufighterMkIF",29}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Portsmouth","difficult_choice2","Herr General, as we prepare to evacuate, a final opportunity to seize British equipment has presented itself.  At this point, our salvage crews will just be grabbing anything that is not bolted down, so the proceeds will likely be a mixture of British vehicles and aircraft.\n\nIf you want to use some more of your influence for a final cache of equipment, now is the time.\n\nYou have %d Commendation Points.\n\nWould you like to use 9 Commendation Points acquire assorted British equipment salvage?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Portsmouth","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Portsmouth","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Portsmouth","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Portsmouth","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Portsmouth","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Portsmouth","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-----------------------------------
-- Objective 1: Raid Southampton --
-----------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Portsmouth","earned_cp_format","Bonus Objective to Raid Southampton completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-------------------------------------------
-- Objective 2: Sink Royal Navy Squadron --
-------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Portsmouth","earned_cp_format2","Bonus Objective to Sink Royal Navy Squadron completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
