-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Greece
p_GR=1

-- 1 Objective defined in scenario:
	-- 0 @end	Capture 3 victory hexes	(4;3)(5;5)(5;7)

-- 3 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	--		OnNewRound(NewRoundAction)			{if EmptyCondition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1940

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{32,1},{33,1},{34,1},{35,1},{33,2},{35,2},{36,2},{33,3},{34,3},{35,3},{36,3}},				-- NE
	{{34,23},{35,23},{34,24},{35,24},{36,24},{33,25},{35,25},{36,25},{34,26},{35,26},{36,26}}	-- SE
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=12, traits={UnitTrait.LowProfile, UnitTrait.NoSupply}},	-- tank "Captured Tanks" NE of Qesarat, per scenario
	{unit_id=13, traits={UnitTrait.ArtySupport}},		-- tank "Captured Tanks" SE camp, per scenario
	{unit_id=15, traits={UnitTrait.LightningAttack}},	-- rcn "Captured Vehicle" N of SE camp, per scenario
	{unit_id=26, traits={UnitTrait.TenaciousDefender}} 	-- inf mtn E of Himara, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_GR, enemy_heroes)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 4,
	eqs = {{"20-70quadruploAA",35},{"L6-40Lf",35}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Valona","difficult_choice","Mein General, we have a problem.  The Italian state of disarray continues to spiral out of control, and nothing exemplifies this more than seeing their own captured tanks being used against us.  My sources have reported to me that an Italian resupply vessel has just arrived in Valona, supposedly bringing some new prototype units as reinforcements.\n\nGiven what we have seen so far, I would bet my monthly salary that these weapons will also be captured and pointing at us before the end of the year.  I say we cut out the middle man, and just seize the equipment for ourselves right now.  The shipment contains more than a few light flamethrower tanks, as well as some prototype air defense vehicles.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 4 Commendation Points to commandeer the Italian weapon shipment?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Valona","option1","Commandeer the vehicles"),
			tooltip= NSLOCTEXT("scenario_Valona","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Valona","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Valona","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Valona","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Valona","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {2,5,8,10,11,14,17,20}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"GRMntInf","",2,900},{"GR105mmM1925-27","HorseTransport",0,900},{"GRMntInf","",0,900},{"GRReserves","",0,900},{"GRReserves","",0,900}},
	{{"GRCavalry","",2,900},{"GR105mmM1925-27","HorseTransport",0,900},{"GRCavalry","",0,900},{"GRReserves","",0,900},{"GRReserves","",0,900}},
	{{"L3-35","",2,900},{"GR105mmM1925-27","HorseTransport",0,900},{"GRMntInf","",0,900},{"GRReserves","",0,900}},
	{{"M13-40","",2,900},{"GR105mmM1925-27","HorseTransport",0,900},{"GRMntInf","",0,900},{"GRReserves","",0,900}},
	{{"AB40","",2,900},{"GR105mmM1925-27","HorseTransport",0,900},{"GRCavalry","",0,900},{"GRCavalry","",0,900}}
}

-- ** Condition for OnNewRound() **
-- Not needed, but ** used in scenario **
function EmptyCondition()
	return true
end

-- ** Effect(NewRoundAction) {if EmptyCondition()} **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_GR, zones[math.random(#zones)], waves[math.random(#waves)])
end
