-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Australia, NZ
p_AU=1
p_NZ=p_AU
	-- 2 [AI]:	UK
p_UK=2

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex		(16;10)	-- Thermopylae
	-- 1 opt	Capture 1 victory hex		(6;16)	-- Bralos
	-- 2 opt	Destroy 22 (Brit.) units	unit IDs 	28,48,26,44,52,42,43,32,46,11,27,50,31,30,29,40,41,45,49,47,25,51,39,33,34,38,35,37,36

-- 5 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Conditon()}
	-- 1x	OnObjective2(ObjectiveStatusAction)	{if Objective2Conditon()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{26,2}},	-- Kouvela, per scenario
	eqs = {{"A10CruiserCS",29}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

------------------------------
-- Objective 1: Raid Bralos --
------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Thermopylae1941","earned_cp_format","Bonus Objective to Raid Bralos completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-------------------------------------------
-- Objective 2: Destroy 22 British Units --
-------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Thermopylae1941","earned_cp_format2","Bonus Objective to destroy 22 British units completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 3, traits={UnitTrait.TenaciousDefender, UnitTrait.DoubleSupport}},	-- at (NZ) in Thermopylae, per scenario
	{unit_id= 5, traits={UnitTrait.TenaciousDefender, UnitTrait.TankKiller, UnitTrait.PreciseOptics}},	-- tank (Aus.) W Bralos, per scenario
	{unit_id= 7, traits={UnitTrait.OverwhelmingAttack, UnitTrait.Provocator, UnitTrait.Evasive, UnitTrait.TenaciousDefender}}, 	-- inf (Aus.) "Brigadier Vasey", per scenario
	{unit_id= 8, traits={UnitTrait.FerociousDefense, UnitTrait.Provocator, UnitTrait.Ambusher}},	-- tank (NZ) "Brigadier Barrowclough" NE Thermopylae, per scenario
	{unit_id=17, traits={UnitTrait.FerociousDefense, UnitTrait.LethalAttack}},		-- aa (Aus.) SW of Bralos, per scenario
	{unit_id=23, traits={UnitTrait.TenaciousDefender, UnitTrait.DoubleSupport}} 	-- aa (NZ) NE Thermopylae, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_AU, enemy_heroes)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 4,
	eqs = {{"Bf109G",19}}
}
-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Thermopylae1941","difficult_choice2","Mein General, we have received an offer to field test an experimental prototype.  If you ask me, it looks like someone welded two 109s together to create a monstrosity, but I have been informed that the aircraft boasts impressive range and firepower.  The current offer will barely give us enough parts to keep a single squadron equipped, but if the design is successful perhaps in the future we can acquire more.\n\nYou have %d Commendation Points.\n\nWould you like to use 4 Commendation Points acquire a collection of prototype Bf109z aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Thermopylae1941","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Thermopylae1941","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Thermopylae1941","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Thermopylae1941","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(0, trade.eqs, Prototypes)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Thermopylae1941","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Thermopylae1941","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_Thermopylae1941","string_C","<bi>Hauptmann Wagner: </>Mein General, in their haste to retreat, it looks like the British failed to sabotage one of their weapon depots.  Some of the artillery tanks there are of a design I do not recognize and could be worth equipping for ourselves.  We've commandeered the contents and you can access them as captured equipment."))
	end
end
