-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Italy
p_IT=1
	-- 2 [AI]:	Germany - Fliegerkorps
p_FJ=2
	-- 3 [AI]:	UK, NZ, Australia, Greece
p_UK=3
p_NZ=p_UK
p_AU=p_UK
p_GR=p_UK

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 2 victory hexes		(28;23)(29;24)	-- Maleme
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Destroy 5 units				unit IDs 94,95,96,93,97	-- aircraft

-- 9 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	Objective1(ObjectiveStatusAction)	{if Objective1Condition()}		-> OnObjective1()
	-- 1x	Objective2(ObjectiveStatusAction)	{if Objective2Condition()}		-> OnObjective2()
	-- 1x	Turn2Italy(StartTurnAction)	{if IsSecondTurn()}
	-- 1x	Turn3Italy(StartTurnAction)	{if IsThirdTurn()}
	-- 1x	Turn17GallandSearch(StartTurnAction)	{if Turn17()}
	-- 1x	Turn18GallandRetire(StartTurnAction)	{if Turn18()}
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{32,31}},	-- air depot, per scenario
	eqs = {{"SpitfireMkII",19},{"BeaufighterMkIF",19},{"StirlingMkI",29}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

--------------
-- Triggers --
--------------

------------------------
-- Messages to player --
------------------------

-- ** Condition for Turn2Italy() **
function IsSecondTurn()
	return world.round == 2
end

-- ** 1x Effect(StartTurnAction) {if IsSecondTurn()} **
function Turn2Italy()
	TutorialMessage(NSLOCTEXT("scenario_OperationMercury","string_Italy1","<bi>Hauptmann Wagner: </>Mein General, our Italian escorts are reporting contact with some British Royal Navy forces.  While they determine the strength of the enemy fleet, I will to continue to hold our naval transports in reserve.  I promise to release the transports to your control as soon as the Italians have cleared the waterways between us and Crete."))
end

-- ** Condition for Turn3Italy() **
function IsThirdTurn()
	return world.round == 3
end

-- ** 1x Effect(StartTurnAction) {if IsThirdTurn()} **
function Turn3Italy()
	TutorialMessage(NSLOCTEXT("scenario_OperationMercury","string_Italy2","<bi>Hauptmann Wagner: </>It would appear that the only fleet that is going to be cleared out of the area is our Italian escorts.  They have been totally overwhelmed by the presence of so many British capital ships.  Under the circumstances, I cannot authorize the release of our naval transports to send our panzers and heavy artillery to Crete.  They'll see the bottom of the Mediterranean before they see the shores of Crete!\n\nWe must rely exclusively on our aircraft and paratroopers for the entire duration of the operation."))
end

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm =3
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_OperationMercury","earned_cp_format","Bonus Objective to Capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------------------------------------------------
-- Objective 2: Destroy all 5 Allied aircraft based on Crete --
---------------------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 3
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox( string.format(tostring( NSLOCTEXT("scenario_OperationMercury","earned_cp_format2","Bonus Objective to Destroy all 5 Allied aircraft based on Crete completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.") ), comm, campaign.comm_points) )
end

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=56, traits={UnitTrait.FerociousDefense, UnitTrait.Readiness, UnitTrait.Vigilant}},	-- inf (Aus.) Rethimnon, per scenario
	{unit_id=60, traits={UnitTrait.AimingAssistance, UnitTrait.CripplingBlow}},	-- inf (NZ) Maleme, per scenario
	{unit_id=76, traits={UnitTrait.Resilient, UnitTrait.OverwhelmingAttack, UnitTrait.ArtySupport}}, 	-- rcn "Major General Freyberg", E of Maleme, per scenario
	{unit_id=79, traits={UnitTrait.Butcher, UnitTrait.FierceFighter}}			-- aa NE of Sternes, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_UK, enemy_heroes)	-- Commonwealth units
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_OperationMercury","string_C","<bi>Hauptmann Wagner: </>Mein General, our forces have seized control of a major British aircraft depot.  From the looks of things, they were in the middle of preparing to evactuate quite a few planes from Crete when our forces arrived.  All of the grounded fighters and bombers are still in fighting condition, and we've commandeered them all.  You can now access them as captured equipment."))
	end
end

-------------
-- He111Z --
-------------

trade = {
	cps = 3,
	eqs = {{"He111Z", 40}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_OperationMercury","difficult_choice2","Mein General, we have received another offer to field test an experimental prototype.  I cannot explain this sudden fascination to attach aircraft together like some sort of Frankenstein's monster, but this time it is Heinkel that has attached two 111s together!  Once again, the result is an aircraft of exceptional range.  The current offer will barely give us enough parts to keep a single squadron equipped, but if the design is successful perhaps in the future we can acquire more.\n\nYou have %d Commendation Points.\n\nWould you like to use 5 Commendation Points acquire a collection of prototype He111z aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_OperationMercury","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_OperationMercury","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_OperationMercury","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_OperationMercury","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Prototypes)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_OperationMercury","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_OperationMercury","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

---------------------
-- Retire Galland? --
---------------------

galland = {
	exists = false,
	id = -1,
	unit = nil,
	eqs = {{"Bf109G",100}}
}

function FindGalland()	-- searches player's Heroes for Galland, by name, and sets (as side-effect) 'gallad' state
	local hero,unit = lib.FindHeroByName(0,galland.name)
	if (hero == nil) then return end	-- not found
	galland.exists = true
	galland.id = hero.id
	galland.unit = unit
end

function UnassignGalland()	-- removes Galland from player's Heroes and sets (as side-effect) 'gallad' state
	if (galland.exists == true and galland.unit ~= nil) then
		world:Exec(world:MakeUnassignHeroAction(galland.unit, galland.id))
		galland.unit = nil	-- no longer a valid association
	end
end

function RetireGalland()
	UnassignGalland()
	if (galland.id ~= -1) then		-- Galland found. Dismiss him!
		world:Exec(world:MakeDismissHeroAction(0, galland.id))
		MessageBox(NSLOCTEXT("scenario_OperationMercury","stringGallandRetire","Major Galland has left your service."))
		galland.id = -1	-- no longer a valid id
	end
end

-- ** Condition for Turn17GallandSearch() **
function Turn17()
	return world.round == 17
end

-- ** 1x Effect(StartTurnAction) {if Turn18()} **
function Turn17GallandSearch()
	FindGalland()	-- sets 'galland' state
end

-- ** Condition for Turn18GallandRetire() **
function Turn18()
	return world.round == 18
end

-- ** 1x Effect(StartTurnAction) {if Turn17()} **
function Turn18GallandRetire()
	if (not galland.exists) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_OperationMercury","difficult_choiceGalland2","Excuse the interruption, but there is an urgent matter regarding one of our best pilots.  Major Galland has proven his excellence time and again, but it seems the time has come for him to advance beyond the cockpit.  High Command would like to recall Major Galland from our roster and offer him a new position.  I hear he could even be next in line for promotion to General of Fighters!\n\nWhile it would be a blow to our roster to lose such an outstanding officer, we have been offered a huge amount of prototype Bf-109Gs as compensation.\n\nWould you agree to release Major Galland from our services or refuse his promotion and fight to keep him in our ranks as a Major?")))
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoiceG")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_OperationMercury","option1Galland","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_OperationMercury","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_OperationMercury","option2Galland","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_OperationMercury","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoiceG" ==> ProcessChoiceG(player,choice)
end

function ProcessChoiceG(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		RetireGalland()
		lib.AddEquipments(player, eqs, Prototypes)
	end

	local choice_made =
	{
		NSLOCTEXT("scenario_OperationMercury","choice_made5","You agree to let Major Galland go.  100 Bf-109G are now available as prototype equipment!"),
		NSLOCTEXT("scenario_OperationMercury","choice_made6","You refuse to release Major Galland for promotion."),
	}
	MessageBox(string.format(tostring(choice_made[choice])))
end
