-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Germany - Target Dummies
p_DE=1
	-- 2 [AI]:	OGE
p_OGE=2

-- 1 Objective defined in scenario:
	-- 0 @end	Capture 1 victory hex	(15;12)	-- already owned

-- 9 Triggers defined in scenario:
	-- 1x	EmilChoice(NewRoundAction)
	-- 1x	MaxChoice(NewRoundAction)					{if Turn2()}
	-- 1x	Turn3Landing(NewRoundAction)				{if Turn3()}
	-- 1x	Turn4CheckMeteor(NewRoundAction)			{if Turn4()}
	-- 1x	MesserschmittSpecial(NewRoundAction)		{if MesserCondition()}
	-- 1x	MesserschmittSpecialChoice(NewRoundAction)	{if Turn6()}
	-- 1x	RudelSpecial(NewRoundAction)				{if Turn7()}
	-- 1x	Rudel(NewRoundAction)						{if RudelCondition()}
	-- 1x	EncounterAction(MoveAction)					{if EncounterCheck()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

--------------
-- Triggers --
--------------

-- offer 19 emil parts first,
-- then offer max on turn 2,
-- then Galland on turn 4,
-- then pre mess message on turn 5,
-- then Messerschmidt on turn 6,
-- then Rudel on turn 7

----------------------
-- CP for equipment --
----------------------

trade = {
	cps  = 2,	-- actually 4, since 2x choices
	eqs  = {{"SturerEmil",19}},	-- prototypes
	units= {{"10-5cmKGepanzerteSfl","",0,0}},	-- also free unit
	zone = {{15,9},{16,9},{15,10},{16,10},{17,10},{14,11},{15,11}}
}

-- ** 1x Effect(NewRoundAction) **
function EmilChoice()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_UndisclosedLocationPO","difficult_choiceEmil","Mein General, there is quite a pile of paperwork awaiting your attention, and while our troops are training, I thought now would be a good time to get through it all.\n\nFirst up, we have received two competing offers for prototype equipment!  The offer from Henschel looks to be giving us a set of prototype parts enough to form one unit of self propelled 12.8cm anti-tank weapons.  An intriguing offer, but I would be concerned that maintaining the unit over time would be problematic with so few extra components available.\n\nAt the same time, Krupp has made an offer of their own.  Instead of a limited supply of parts, they are willing to offer us a unit of self propelled 10.5cm anti-tank weapon and enough parts to maintain it indefinitely.  The catch is that the unit will be permanently half strength, because so few complete chassis of the vehicle exist.\n\nKeep in mind if we take this first offer from Henschel, we might not have enough influence to acquire the Krupp design as well.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 3 Commendation Points for the Henschel anti-tank prototype or save them for the Krupp offer?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option1Emil","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option2Emil","Wait for different offer"),
			tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Prototypes)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made1","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made2","You choose to wait for an alternate offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

uniquemax = false

-- ** Condition for MaxChoice() **
function Turn2()
	return world.round == 2
end

-- ** 1x Effect(NewRoundAction) {if Turn2()} **
function MaxChoice()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_UndisclosedLocationPO","difficult_choiceMax","Krupp still has their offer for us, Mein General.  Remember that if we do take it, we can probably keep it running indefinitely, but it is only half strength compared to our normal units.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 3 Commendation Points for this unique unit?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice2")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option1Max","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option2Max","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice2" ==> ProcessChoice2(player,choice)
end

function ProcessChoice2(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)

		uniquemax = true
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made3","You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made4","You choose to decline the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

----------------------------
-- Spawn selected unit(s) --
----------------------------

-- ** Condition for Turn3Landing() **
function Turn3()
	return world.round == 3
end

-- ** 1x Effect(NewRoundAction) {if Turn3()} **
function Turn3Landing(action)
	if (uniquemax == true) then
		TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_max","The Krupp anti-tank prototype has arrived on the training field."))
		lib.SpawnWave(0, trade.zone, trade.units)	-- create & place player unit
	end
end

--------------------------------
-- Token for future prototype --
--------------------------------

uniquemeteor = false

-- ** Condition for Turn4CheckMeteor() **
function Turn4()
	return world.round == 4
end

-- ** 1x Effect(NewRoundAction) {if Turn4()} **
function Turn4CheckMeteor()	-- determine how many points of MeteorMkIII are captured (see: AO40 campaign, Epsom scenario)
	if (lib.CountEquipment(0, "MeteorMkIII") >= 1) then
		uniquemeteor = true
	end
end

-- ** Condition for MesserschmittSpecial() **
function MesserCondition()
	return uniquemeteor == true
end

-- ** 1x Effect(NewRoundAction) {if MesserCondition()} **
function MesserschmittSpecial()
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt1","<bi>Hauptmann Wagner: </>I have just received word that our next order of business is actually here to speak to you in person.  Mein General, may I introduce you to Director Wilhelm Messerschmitt..."))
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt2","<bi>Director Wilhelm Messerschmitt: </>Ahhh Herr General, it is an honor to make your acquaintance!  I understand you have been putting my fighter designs to excellent use, ja?"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt3","<bi>Hauptmann Wagner: </>Thanks to your designs, our pilots have had a decisive advantage in aerial combat in many campaigns so far.  The superior performance of your fighters is well respected and most appreciated, Director."), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt4","<bi>Director Messerschmitt: </>Yes, yes, yes.  Good, very good!  But I have not come all this way to seek praise over my designs from last decade.  I come to talk to you of the future...  Of aircraft free of the design limitations of mere spinning propellers!"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt5","<bi>Hauptmann Wagner: </>Pardon me, Director, but Zeppelins and other airships will never..."), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt6","<bi>Director Messerschmitt: </>Young Hauptmann Wagner, I do not speak of a future you have already seen go down in flames, I speak of a future you have not even begun to conceive!"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt7","<bi>Director Messerschmitt: </>Herr General, it has come to my attention you retrieved something very special during your visit to Britain last year.  Something so special, you couldn't even properly identify what it was, ja?"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt8","<bi>Director Messerschmitt: </>I would like to acquire those technical documents.  I believe there are secrets in those documents that could dramatically accelerate my own research in new aircraft technologies!"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_Messerschmitt9","<bi>Director Messerschmitt: </>However, I am afraid I cannot offer you any sort of immediate compensation for them... it will take many sleepless nights of work before we will even know if the technical documents will be of real use to us.  But if they are, I will promise you something wonderful in the future!"), false)
end

-- ** Condition for MesserschmittSpecialChoice() **
function Turn6()
	return world.round == 6
end

-- ** 1x Effect(NewRoundAction) {if (Turn6)} **
function MesserschmittSpecialChoice()
	if (uniquemeteor == true) then
		local message = string.format(tostring(NSLOCTEXT("scenario_UndisclosedLocationPO","difficult_choiceMesserschmitt","Mein General, given that we cannot even properly identify or read the technical documents we have in our possession, I see no harm in handing them over to Director Messerschmitt.  Our only other use for them is kindling for a fire, and that seems to be a tragic waste.\n\nWill you agree to hand over the captured British files?")))
		local choose_action = world:MakeChooseAction(0, message, "ProcessChoice3")
		choose_action.options = {
			{
				title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option1Messer","Authorize the exchange"),
				tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option1_tooltip","")
			},
			{
				title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option2Messer","Refuse the offer"),
				tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option2_tooltip","")
			}
		}
		world:Exec(choose_action)	-- "ProcessChoice3" ==> ProcessChoice3(player,choice)
	end
end

function ProcessChoice3(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		lib.AddEquipments(0, {{"Me262A", 5}}, Prototypes)
	end
	lib.AddEquipments(player, {{"MeteorMkIII", -1}}, Captured)	-- in either case, reduce the Meteor parts to 0
	local choice_made =
	{
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made7","You agree hand over the technical documents.  You now have a promise from Director Messerschmitt."),
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made8","You refuse and instead destroy the technical documents."),
	}
	MessageBox(string.format(tostring(choice_made[choice])))
end

---------------------
-- Player Hero(es) --
---------------------

uniquerudel = false

-- ** Condition for RudelSpecial() **
function Turn7()
	return world.round == 7
end

-- ** 1x Effect(NewRoundAction) {if Turn7()} **
function RudelSpecial()
	local message = string.format(tostring(NSLOCTEXT("scenario_UndisclosedLocationPO","difficult_choiceRudel","Mein General, one final issue for us to go over.  And this time, I'm glad he isn't here making his case in person.  Ignoring the attached package of schnauzer treats addressed to me, Hans-Ulrich Rudel has sent another request for a combat transfer.  I must say, the man is utterly relentless, but unlike before, this request comes with very impressive training certifications he has completed.  I think the time has finally come to make a final decision on him serving under your Command.\n\nWill we finally accept Hans-Ulrich Rudel into our bomber roster and see what he is capable of?  Or will we forever reject him?")))
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice4")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option1Rud","Recruit Rudel"),
			tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_UndisclosedLocationPO","option2Rud","Dismiss Rudel"),
			tooltip= NSLOCTEXT("scenario_UndisclosedLocationPO","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice4" ==> ProcessChoice4(player,choice)
end

function ProcessChoice4(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		uniquerudel = true
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made9","You accept Rudel into your command.  You will now have a chance to customize his three hero traits to mark the completion of his training."),
		NSLOCTEXT("scenario_UndisclosedLocationPO","choice_made10","You ban Rudel from military service under your command."),
	}
	MessageBox(string.format(tostring(choice_made[choice])))
end

-- ** Condition for Rudel() **
function RudelCondition()
	return uniquerudel == true
end

-- ** 1x Effect(NewRoundAction) {if RudelCondition()} **
function Rudel()
	RudelOfferChoice1()
end

rudel_traits = {UnitTrait.Legendary}

function RudelOfferChoice1()
	local message = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice1","Choose the first trait for Rudel.  Will you focus his first ability on unrelenting offense or flexible maneuvering?")
	local choose_action = world:MakeChooseAction(0, message, "RudelProcessChoice1")
	choose_action.options = {
		{
			title = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice1_option1","Double Attack"),
		},
		{
			title = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice1_option2","Double Move"),
		}
	}
	world:Exec(choose_action)	-- "RudelProcessChoice1" ==> RudelProcessChoice1(player,choice)
end

function RudelProcessChoice1(player, choice)
	local options = {UnitTrait.DoubleAttack, UnitTrait.DoubleMove}
	table.insert(rudel_traits, options[choice])	-- append
	RudelOfferChoice2()
end

function RudelOfferChoice2()
	local message = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice2","Choose the second trait for Rudel.  Will you focus his second ability on strong defensive fire or the ability to avoid enemy air defenses and fighters?")
	local choose_action = world:MakeChooseAction(0, message, "RudelProcessChoice2")
	choose_action.options = {
		{
			title = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice2_option1","Aggressive Counterattack"),
		},
		{
			title = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice2_option2","Lightning Attack"),
		}
	}
	world:Exec(choose_action)	-- "RudelProcessChoice2" ==> RudelProcessChoice2(player,choice)
end

function RudelProcessChoice2(player, choice)
	local options = {UnitTrait.AggressiveCounterattack, UnitTrait.LightningAttack}
	table.insert(rudel_traits, options[choice])	-- append
	RudelOfferChoice3()
end

function RudelOfferChoice3()
	local message = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice3","Choose the final trait for Rudel.  Will you focus his last ability on piercing enemy protection or extra tank busting power?")
	local choose_action = world:MakeChooseAction(0, message, "RudelProcessChoice3")
	choose_action.options = {
		{
			title = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice3_option1","Ignores Entrenchment"),
		},
		{
			title = NSLOCTEXT("scenario_UndisclosedLocationPO","rudel_choice3_option2","Tank Killer"),
		}
	}
	world:Exec(choose_action)	-- "RudelProcessChoice3" ==> RudelProcessChoice3(player,choice)
end

function RudelProcessChoice3(player, choice)
	local options = {UnitTrait.IgnoresEntrenchment, UnitTrait.TankKiller}
	table.insert(rudel_traits, options[choice])	-- append
	RudelCreate()
end

rudel_hero = {
	{
		portrait = "/Game/Gui/Common/Heroes/de_af_rudel.de_af_rudel",
		name = NSLOCTEXT("scenario_UndisclosedLocationPO","Hans-Ulrich Rudel","Hans-Ulrich Rudel"),
		traits = rudel_traits,	-- see above
		unit_classes = {UnitClass.TacticalBomber}
	}
}

function RudelCreate()
	lib.CreateAndAssignHeroes(0, rudel_hero)
end

-----------------------------------
-- Proximity/Encounter detection --
-----------------------------------

------------------------
-- Messages to player --
------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =
	{
		player = 0,
	}
	local filter2 =
	{
		player = p_OGE,
		id = {12,13,14,15,16,17,18,19,20,21,22,23,24,25,26},	-- unit IDs of units in SW map corner fortified "Restricted Area" zone, per scenario
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter1","<bi>Sentry: </>Halt!  Where are your papers?  Show me your papers!"))
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter2","<bi>Officer: </>Calm down, Baer.  Don't you recognize Wehrmacht uniforms when you see them?  I'm sure our army friends are here for a good reason, ja?"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter3","<bi>Hauptmann Wagner: </>Actually, I was supervising the training of some of our newest recruits.  I guess they also need some training in map reading and navigation, because we appear to have gotten lost.  In fact my maps don't even show any facilities in this area."), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter4","<bi>Officer: </>And why would they?  This is not an army site, afterall.  If you would be kind enough to show me your map, I'll be more than happy to help guide you on your way."), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter5","<bi>The black outfitted officer takes a moment to inspect the map.</>"), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter6","<bi>Officer: </>Tsk tsk, it looks like your map was being read upside down!  You travelled too far west along the Vistula, when you probably thought you were going east.  You should be able to follow the river back, and then turn north at the first village you come across."), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter7","<bi>Sentry: </>We need to be reporting this incident..."), false)
	TutorialMessage(NSLOCTEXT("scenario_UndisclosedLocationPO","string_encounter8","<bi>Officer: </>Silence!\n\nI apologize for my overeager subordinate, Hauptmann.  But now that you have your bearings, I must insist you return to your training grounds.  And don't worry about this little mishap, I'll pass it up the chain so the Wehrmacht is better informed of potentially restricted areas.  To avoid future misunderstandings, of course."), false)
end
