-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 4 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex	(19;10)	-- Raseiniai
	-- 1 opt	Capture 1 victory hex	(32;28)	-- Vilnius
	-- 2 opt	Capture 1 victory hex	(31;4)	-- Baisogala
	-- 3 opt	Destroy 30 air units	unit IDs 23,24,25,29,28,30,22,14,15,16,17,20,18,19,21,1,26,4,5,10,2,0,27,6,7,12,13,11,8,9,3

-- 9 Triggers defined in scenario:
	-- 1x	AxisMinor(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 1x	OnObjective2(CaptureFlagAction)		{if Objective2Condition()}
	-- 1x	OnObjective3(CaptureFlagAction)		{if Objective3Condition()}
	-- 1x	Turn7Spanish(NewRoundAction)		{if IsSeventhTurn()}
	-- 1x	EncounterAction(MoveAction)			{if EncounterCheck()}
	-- 		LaunchAllAircraft(NewRoundAction)	{if world.round >= 6}
	-- 		LaunchAllAircraftNE(NewRoundAction)	{if world.round >= 10}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- IDs of grounded aircraft in this scenario
grounded_units = {0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22}
grounded_unitsNE = {23,24,25,28,29,30}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=33, traits={UnitTrait.IncMaxOverstrength, UnitTrait.NoReplace}},	-- tank "2nd Tank Division" WSW Baisogala, per scenario
	{unit_id=34, traits={UnitTrait.NoSurrender, UnitTrait.DoubleAttack}} 		-- tank "Major General Solyankin" SW Baisogala, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

-------------------
-- Prestige sink --
-------------------

eqs = {{"L6-40Lf",35},{"M14-41",35},{"38MToldiI",35}}

-- ** 1x Effect(NewRoundAction) **
function AxisMinor()
	local message = string.format(tostring(NSLOCTEXT("scenario_Raseiniai","difficult_choiceAxisMinor","Mein General, we have received a special offer from our allies.  It seems the Italians and Hungarians are willing to lend of a collection of their tanks in exchange for a considerable amount of supplies.  The Italians are offering some light flame tanks and a brand new medium tank design while the Hungarians have more of their Toldi tanks up for trade.\n\nThey are asking for what will amount to half of our supply stockpile in exchange though, so we might want to consider this offer carefully.\n\nCan we afford to exchange half of our supplies for a collection of Italian and Hungarian tanks?")))
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Raseiniai","option1AxisMinor","Accept the offer"),
			tooltip= NSLOCTEXT("scenario_Raseiniai","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Raseiniai","option2AxisMinor","Reject the offer"),
			tooltip= NSLOCTEXT("scenario_Raseiniai","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		lib.AddEquipments(player, eqs, Captured)

		local p = world:GetPlayer(player)
		p.prestige = math.ceil(p.prestige/2)  -- remove 50% of prestige
	end
	local choice_madeAxisMinor =
	{
		NSLOCTEXT("scenario_Raseiniai","choice_made9","You accept the offer at a cost of half of your supplies."),
		NSLOCTEXT("scenario_Raseiniai","choice_made10","You decline the offer."),
	}
	MessageBox(string.format(tostring(choice_madeAxisMinor[choice])))
end

--------------------------
-- Gift unit, equipment --
--------------------------

gift = {
	eqs  = {{"ROAH-IV",35},{"HUCa135",35}},
	units= {{"AzulInfantry","OpelBlitz",0,1000}},	-- also free unit
	zone = {{7,27},{7,28},{8,28},{6,29},{7,29},{7,30}}
}

-- ** Condition for Turn7Spanish() **
function IsSeventhTurn()
	return world.round == 7
end

-- ** 1x Effect(NewRoundAction) {if IsSeventhTurn()} **
function Turn7Spanish(action)
	-- skip if already have it:
	local found = false
	for _,u in pairs(world.units) do	-- for all units
		if (u.owner_id == 0) then	-- that belong to player
			if (u.type.name == "AzulInfantry") then found=true; break end
		end
	end
	if (not found) then
		TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_SPI1","<bi>Hauptmann Wagner: </>Special reinforcements have arrived, mein General.  From our Spanish friends, a special detachment of infantry soldiers are at our disposal."))
		TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_SPI2","<bi>Hauptmann Wagner: </>It seems their unit is especially skilled at close combat encounters.  Their talents should prove quite useful in urban conflict zones."), false)
		TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_SPI5","<bi>Hauptmann Wagner: </>The infantry have arrived near Goldap, and the tanks and bombers are available in limited stocks to purchase as you see fit."), false)
		lib.SpawnWave(0, gift.zone, gift.units)	-- create & place player unit
	end
	TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_SPI3","<bi>Hauptmann Wagner: </>Additionally, Romania and Hungary have lent us of some of their equipment to use."), false)
	TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_SPI4","<bi>Hauptmann Wagner: </>These Romanian light tanks are not very advanced, but their anti-personel firepower is impressive.  The Hungarian bombers have superior range over our Stukas, though at the cost of a reduced payload."), false)
	lib.AddEquipments(0, gift.eqs, Captured)
end

----------------------------------
-- Objective 1: Control Vilnius --
----------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Raseiniai","earned_cp_format","Bonus Objective to control Vilinus completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

------------------------------------
-- Objective 2: Control Baisogala --
------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Raseiniai","earned_cp_format2","Bonus Objective to control Baisogala completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------------------------------
-- Objective 3: Destroy 30 Soviet Aircraft --
---------------------------------------------

-- ** Condition for OnObjective3() **
function Objective3Condition(action)
	return action.side == 0 and action.objective == 3 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective3Condition()} **
function OnObjective3(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Raseiniai","earned_cp_format3","Bonus Objective to destroy 30 Soviet aircraft completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------------
-- Proximity/Encounter detection --
-----------------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =
	{
		player = 0,
	}
	local filter2 =
	{
		player = p_RU,
		id = {31,32,33,34,39,92,93},	-- KV-1/40 units of "2nd Tank Division" NE near Baisogala, per scenario
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_kv1","<bi>Hauptmann Wagner: </>Mein General, our forces have reported unexpected contact with enemy heavy tanks!"))
	TutorialMessage(NSLOCTEXT("scenario_Raseiniai","string_kv2","<bi>Hauptmann Wagner: </>They're requesting immediate support, as small arms and other light weaponry seems to have no effect on these new tanks."), false)
end

-----------------------
-- Grounded aircraft --
-----------------------

-- This table specifies which type of grounded aircraft converts to which normal aircraft
grounded_to_air_types =
{
	["GroundedPolikarpovI16"] = "PolikarpovI16",
	["GroundedLaGG3"] = "LaGG3",
	["GroundedMiG3"] = "MiG3",
	["GroundedYakovlevYak1"] = "YakovlevYak1",
	["GroundedTupolevSB"] = "TupolevSB",
	["GroundedPetlyakovPe2"] = "PetlyakovPe2",
	["GroundedPetlyakovPe8"] = "PetlyakovPe8"
}

-- Support function: LaunchAircraft() selects the given unit ID from the (given) grounded_to_air_types table and upgrades it to the corresponding air unit
function LaunchAircraft(unit_id)
	local unit = world:GetUnit(unit_id)
	if (unit == nil) then return end			-- unit destroyed?

	local new_type = grounded_to_air_types[unit.type.name]
	if (new_type == nil) then return end		-- we don't know this unit type, ignore

	local hex = world:GetHex(unit.position)
	if (hex:GetUnit(1) ~= nil) then return end	-- air space above the unit is occupied, cannot launch

	local upgrade_action = world:MakeUpgradeAction(unit, new_type, "", unit.overstr)
	upgrade_action.cost = 0
	upgrade_action.slots = 0
	upgrade_action.xp_penalty = 0
	world:Exec(upgrade_action)
end

-- ** Effect(NewRoundAction) {if world.round >= 6 and #grounded_units > 0} **
function LaunchAllAircraft()	-- Launch aircraft on turn 6
	if (world.round < 6 or #grounded_units <= 0) then return end

	while (#grounded_units > 0) do LaunchAircraft(table.remove(grounded_units)) end	-- @TODO: test
end

-- ** Effect(NewRoundAction) {if world.round >= 10 and #grounded_unitsNE > 0} **
function LaunchAllAircraftNE()	-- Launch aircraft on turn 10
	if (world.round < 10 or #grounded_unitsNE <= 0) then return end

	while (#grounded_unitsNE > 0) do LaunchAircraft(table.remove(grounded_unitsNE)) end	-- @TODO: test
end
