-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1
	-- 2 [AI]:	USSR - Rebels
p_Reb=2

-- 3 Objectives defined in scenario:
	-- 0 		Capture all victory hexes
	-- 1 opt	Capture 2 victory hexes		(9;1)(22;3)	-- Parnu and Tartu
	-- 2 opt	Unit must survive			unit ID 96	-- Wagner

-- 7 Triggers defined in scenario:
	-- 1x	PlayerHero(NewRoundAction)	-- Wagner
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 1x	EncounterAction(MoveAction)			{if EncounterCheck()}
	-- 		LaunchAllAircraft(NewRoundAction)	{if world.round >= 6}
	-- 1x	OnVictory(VictoryAction)	-- Wagner

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=49, traits={UnitTrait.NoRetaliation}},	-- inf in E Pskov, per scenario
	{unit_id=87, traits={UnitTrait.OverwhelmingAttack,UnitTrait.QuadripleGun}}, 	-- inf NE of Riga, per scenario
	{unit_id=91, traits={UnitTrait.Camouflage}} 	-- tank E of Riga, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignEnemyHeroes(p_RU, enemy_heroes)
end

---------------------
-- Player Hero(es) --
---------------------

wagner = {
	{unit_id=96, name=NSLOCTEXT("scenario_StalinLine","Stefan_Wagner","Stefan Wagner"), portrait="/Game/Gui/Common/Heroes/de_in_wagner.de_in_wagner", traits = {UnitTrait.Leadership, UnitTrait.NoSplit, UnitTrait.ArtySupport}}
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, wagner, true)	-- create silently, without usual Hero pop-up
end

-------------------------------------------------------
-- Objective 1: Capture Parnu and Tartu before Pskov --
-------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_StalinLine","earned_cp_format","Bonus Objective to Capture Parnu and Tartu before Pskov completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------
-- PanzerZug --
---------------

eq = {
	units= {{"ArmouredTrain","",0,0}},
	zone = {{18,31},{18,32}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart(action)
	TutorialMessage(NSLOCTEXT("scenario_StalinLine","string_PanzerZug2","<bi>Hauptmann Wagner: </>More special reinforcements have arrived, Mein General.  This time we have been sent a brand new Panzerzug for our own use.\n\nJust remember that whenever you deploy this particular unit to the field, it is restricted to moving on railroad lines only."))
	lib.SpawnWave(0, eq.zone, eq.units, true)	-- create & place player unit as auxiliary
end

-----------------------------------
-- Proximity/Encounter detection --
-----------------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =
	{
		player = 0,
	}
	local filter2 =
	{
		player = 2,			-- Player 2 (3), Rebels (partisans) N around Tartu, per scenario
		id = {1,2,3,4,5},	-- Partisan unit IDs
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_StalinLine","string_partis","<bi>Hauptmann Wagner: </>Our forces have reported a curious situation.  Some of the Soviet units seem to be firing upon each other...  There is nothing in our intelligence reports that might explain the situation, and it could very well just be a trap.  I suggest we continue treat all contacts as hostile, given that we have not received any communication from these fighters ourselves."))
end

-----------------------
-- Grounded aircraft --
-----------------------

-- IDs of grounded aircraft in this scenario
grounded_units = {57,59,54,53,55,58,60,56,61,63,64,62,65}

-- This table specifies which type of grounded aircraft converts to which normal aircraft
grounded_to_air_types =
{
	["GroundedPolikarpovI16"] = "PolikarpovI16",
	["GroundedLaGG3"] = "LaGG3",
	["GroundedMiG3"] = "MiG3",
	["GroundedYakovlevYak1"] = "YakovlevYak1",
	["GroundedTupolevSB"] = "TupolevSB",
	["GroundedPetlyakovPe2"] = "PetlyakovPe2",
	["GroundedPetlyakovPe8"] = "PetlyakovPe8"
}

function LaunchAircraft(unit_id)
	local unit = world:GetUnit(unit_id)
	if (unit == nil) then		-- unit destroyed?
		return
	end

	local new_type = grounded_to_air_types[unit.type.name]
	if (new_type == nil) then		-- we don't know this unit type, ignore
		return
	end

	local hex = world:GetHex(unit.position)
	if (hex:GetUnit(1) ~= nil) then		-- air space above the unit is occupied, cannot launch
		return
	end

	local upgrade_action = world:MakeUpgradeAction(unit, new_type, "", unit.overstr)
	upgrade_action.cost = 0
	upgrade_action.slots = 0
	upgrade_action.xp_penalty = 0
	world:Exec(upgrade_action)
end

-- @FIXME: will be called _every_ round, even though only needs to fire 1x
function LaunchAllAircraft()	-- Launch aircraft starting from turn 6
	if (world.round < 6) then return end

	for _,id in ipairs(grounded_units) do
		LaunchAircraft(id)
	end
end

---------------------------------------------------------
-- Objective 2: Wagner's Halftrack Survives the Battle --
---------------------------------------------------------

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** 1x Effect(VictoryAction) **
-- ** checked at scenario end **
function OnVictory()
	if (GetObjectiveStatus(0,2) == ObjectiveStatus.Fail) then return end

	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_StalinLine","earned_cp_format2","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
