-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 3 Objectives defined in scenario:
	-- 0 		Capture all victory hexes
	-- 1 opt	Destroy 12 units	unit IDs 5,6,7,8,9,11,12,13,14,15,16,17,18,19,20,21,22 	-- ships
	-- 2 opt	Unit must survive	unit ID 125	-- Wagner

-- 4 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	PlayerHero(NewRoundAction)	-- Wagner
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 1x	OnVictory(VictoryAction)	-- Wagner

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

---------------------
-- Player Hero(es) --
---------------------

wagner = {
	{unit_id=125, name=NSLOCTEXT("scenario_Tallinn","Stefan_Wagner","Stefan Wagner"), portrait="/Game/Gui/Common/Heroes/de_in_wagner.de_in_wagner", traits = {UnitTrait.Leadership, UnitTrait.NoSplit, UnitTrait.ArtySupport}}
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, wagner, true)	-- create silently, without usual Hero pop-up
end

---------------------------------------
-- Objective 1: Sink 12 Soviet Ships --
---------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Tallinn","earned_cp_format","Bonus Objective to sink Sink 12 Soviet Ships before Tallinn is secured completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 4,
	eqs = {{"LaGG3",24},{"PetlyakovPe2",31},{"PetlyakovPe8",19}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Tallinn","difficult_choice2","Mein General, our salvage crews have come back with a progress report on all of the Soviet airfields we have overrun.  Although the overwhelming majority of enemy aircraft on the ground have been destroyed, there were a few that we actually captured intact.  I am told the designs are not exactly cutting edge, but perhaps you can find some use for them.\n\nYou have %d Commendation Points.\n\nWould you like to use 4 Commendation Points to acquire an assorted collection of captured Soviet fighter and bomber aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Tallinn","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Tallinn","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Tallinn","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Tallinn","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Tallinn","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Tallinn","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-------------------------------------------------------------------
-- Objective 2: Hauptmann Wagner's Halftrack survives the battle --
-------------------------------------------------------------------

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** 1x Effect(VictoryAction) **
-- ** checked at scenario end **
function OnVictory()
	if (GetObjectiveStatus(0,2) == ObjectiveStatus.Fail) then return end

	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Tallinn","earned_cp_format2","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
