-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 3 Objectives defined in scenario:
	-- 0 		Capture all victory hexes
	-- 1 opt	Custom objective	Player1CustomSuccess() | Fail()
	-- 2 opt	Unit must survive	unit ID 122	-- Wagner

-- 7 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	PlayerHero(NewRoundAction)	-- Wagner
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	MineHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 		OnMineLaying(MoveAction)
	-- 1x	OnVictory(VictoryAction)	-- Wagner

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

mine_locations =	-- [1] is VP location, [2] is table of locations for (up to 4) strongpoints
{
	{{19,4}, {{19,3},{20,4},{20,5}}},			-- fort WSW of Leningrad, near Gulf
	{{22,7}, {{22,6},{23,6},{23,7}}},			-- fort SW  of Leningrad
	{{26,7}, {{25,6},{26,6},{27,6},{27,7}}},	-- fort S   of Leningrad
	{{30,8}, {{28,7},{29,7},{30,7},{31,7}}}		-- fort SSE of Leningrad
}
completed_mine_locations = {}
mines_deployed = 0

mine_layers = {115,116,117}	-- unit IDs, per scenario

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 0, traits={UnitTrait.SmartEntrenchment, UnitTrait.Camouflage}},	-- tank KV-1/41 NW Krasnogvardeysk, per scenario
	{unit_id= 1, traits={UnitTrait.Vigilant, UnitTrait.FastEntrenchment, UnitTrait.Camouflage, UnitTrait.Ambusher}},	-- tank "Zinoviy Kolobanov" in Krasnogvardeysk, per scenario
	{unit_id= 2, traits={UnitTrait.Vigilant, UnitTrait.Camouflage}},			-- tank KV-1/41  E Krasnogvardeysk, per scenario
	{unit_id=77, traits={UnitTrait.AimingAssistance, UnitTrait.ATSupport}},		-- inf SW of Novgorod, per scenario
	{unit_id=80, traits={UnitTrait.AimingAssistance, UnitTrait.ArtySupport}} 	-- inf  N of Novgorod, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

---------------------
-- Player Hero(es) --
---------------------

wagner = {
	{unit_id=122, name=NSLOCTEXT("scenario_ApproachingLeningrad","Stefan_Wagner","Stefan Wagner"), portrait="/Game/Gui/Common/Heroes/de_in_wagner.de_in_wagner", traits = {UnitTrait.Leadership, UnitTrait.NoSplit, UnitTrait.ArtySupport}}
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, wagner, true)	-- create silently, without usual Hero pop-up
end

-----------------
-- Mine heroes --
-----------------

mine_heroes = {
	-- minelaying trucks:
	{unit_id=115, name = NSLOCTEXT("scenario_ApproachingLeningrad","Sips","Sips"), traits={UnitTrait.NoSplit}},
	{unit_id=116, name = NSLOCTEXT("scenario_ApproachingLeningrad","Sjin","Sjin"), traits={UnitTrait.NoSplit}},
	{unit_id=117, name = NSLOCTEXT("scenario_ApproachingLeningrad","Angory_Thomas","Angory Thomas"), traits={UnitTrait.NoSplit}}
}

-- ** 1x Effect(NewRoundAction) **
function MineHero()
	lib.CreateAndAssignHeroes(0, mine_heroes, true)	-- create silently, without usual Hero pop-up
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 5,
	eqs = {{"Bf109Z",26}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_ApproachingLeningrad","difficult_choice2","Mein General, we have received an offer to replenish some of our prototype aircraft.  If you have been impressed with the performance of the Bf-109z, or finally wish to try it out, now is the opportunity to acquire more spare parts for them.\n\nYou have %d Commendation Points.\n\nWould you like to use 5 Commendation Points acquire a collection of prototype Bf109z aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_ApproachingLeningrad","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_ApproachingLeningrad","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_ApproachingLeningrad","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_ApproachingLeningrad","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Prototypes)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_ApproachingLeningrad","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_ApproachingLeningrad","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-----------------------------------------------------------
-- Objective 1: Set up 4 Siege Bunkers outside Leningrad --
-----------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_ApproachingLeningrad","earned_cp_format","Bonus Objective to deploy 4 sets of Siege Bunkers outside Leningrad completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------------------------------------
-- Objective 1: Set up 4 Siege Bunkers outside Leningrad --
-----------------------------------------------------------

-- ** Condition for Objective 1 success **
function Player1CustomSuccess(action)
	return mines_deployed >= 4
end

-- ** Condition for Objective 1 failure **
-- ** checked at scenario end **
function Player1CustomFail(action)
	return action:GetActionClass() == "TurnsLimitAction" and mines_deployed < 4
end

-------------------------------------------------------------------
-- Objective 2: Hauptmann Wagner's Halftrack survives the battle --
-------------------------------------------------------------------

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** 1x Effect(VictoryAction) **
-- ** checked at scenario end **
function OnVictory()
	if (GetObjectiveStatus(0,2) == ObjectiveStatus.Fail) then return end

	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_ApproachingLeningrad","earned_cp_format2","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------
-- Minelaying units --
----------------------

-- ** Effect(MoveAction) **
function OnMineLaying(action)
	-- Check if moved unit is one of mine layers
	if (not lib.IsItemInTable(mine_layers, action.unit)) then return end

	-- Check if we already planted mines in this location
	if (lib.IsItemInTable(completed_mine_locations, action.position)) then return end

	-- Check if we need to lay any mines in this hex
	local lay_hexes = nil
	for index,mine_location in ipairs(mine_locations) do
		if (mine_location[1] == action.position) then
			lay_hexes = mine_location[2]
			break
		end
	end
	if (lay_hexes == nil) then return end

	-- 1. Spawn land mine units
	local player = 0
	local units = {{"Strongpoint","",10,0},{"Strongpoint","",10,0} }
	lib.SpawnWave(player, lay_hexes, units, true)	-- create & place strongpoints as auxiliary
	-- 2. Increase the counter
	mines_deployed = mines_deployed + 1
	-- 3. Display message
	MessageBox("", string.format(tostring(NSLOCTEXT("scenario_ApproachingLeningrad","mines_layed","One set of Siege Bunkers successfully deployed.\n\nTotal Siege Bunker sets deployed is now %d.")), mines_deployed))
	-- 4. Remember that we've planted mines in this location
	table.insert(completed_mine_locations, action.position)
end
