-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	Germany - 18th Panzer
p_18div=1
	-- 2 [AI]:	USSR
p_RU=2

-- 3 Objectives defined in scenario:
	-- 0 		Capture all victory hexes
	-- 1 opt	Capture 2 victory hexes		(6;14)(2;21)	-- Bialystok and Grodno
	-- 2 opt	Unit must survive			unit ID 9		-- Wagner

-- 7 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	PlayerHero(NewRoundAction)	-- Wagner
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 1x	OnObjective2(CaptureFlagAction)		{if Objective2Condition()}
	-- 		LaunchAllAircraft(NewRoundAction)	{if world.round >= 3}
	-- 1x	OnVictory(VictoryAction)	-- Wagner

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=67, traits={UnitTrait.FearsomeReputation, UnitTrait.AimingAssistance}},	-- tank E of Bialystok, per scenario
	{unit_id=99, traits={UnitTrait.OverwhelmingAttack, UnitTrait.LightningAttack}},	-- cav NW of Minsk, per scenario
	{unit_id=87, traits={UnitTrait.DoubleSupport, UnitTrait.Readiness}},	-- at in column SE of Baranovichi, per scenario
	{unit_id=42, traits={UnitTrait.Butcher, UnitTrait.Evasive}} 	-- inf eng in Minsk, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

---------------------
-- Player Hero(es) --
---------------------

wagner = {
	{unit_id=9, name=NSLOCTEXT("scenario_Minsk1941","Stefan_Wagner","Stefan Wagner"), portrait="/Game/Gui/Common/Heroes/de_in_wagner.de_in_wagner", traits = {UnitTrait.Leadership, UnitTrait.NoSplit, UnitTrait.ArtySupport}}
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, wagner, true)	-- create silently, without usual Hero pop-up
end

---------------
-- PanzerZug --
---------------

eq = {
	units= {{"ArmouredTrain","",0,0}},
	zone = {{2,2},{3,2},{4,2}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart(action)
	TutorialMessage(NSLOCTEXT("scenario_Minsk1941","string_PanzerZug2","<bi>Hauptmann Wagner: </>More special reinforcements have arrived, Mein General.  This time we have been sent a brand new Panzerzug for our own use.\n\nJust remember that whenever you deploy this particular unit to the field, it is restricted to moving on railroad lines only."))
	lib.SpawnWave(0, eq.zone, eq.units, true)	-- create & place player unit as auxiliary
end

---------------------------------------------------------------------------
-- Objective 1: Capture Bialystok and Grodno before the last Victory Hex --
---------------------------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Minsk1941","earned_cp_format","Bonus Objective to Capture Bialystok and Grodno before the last Victory Hex completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-------------------------------------------------------------------
-- Objective 2: Hauptmann Wagner's Halftrack survives the battle --
-------------------------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Minsk1941","earned_cp_format2","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-------------------------------------------------------------------
-- Objective 2: Hauptmann Wagner's Halftrack survives the battle --
-------------------------------------------------------------------

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** 1x Effect(VictoryAction) **
-- ** checked at scenario end **
function OnVictory()
	if (GetObjectiveStatus(0,2) == ObjectiveStatus.Fail) then return end

	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
-- @FIXME: duplicated from OnObjective2(), above:
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Minsk1941","earned_cp_format2","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------
-- Grounded aircraft --
-----------------------

-- IDs of grounded aircraft in this scenario
grounded_units = {50,57,53,59,54,58,49,55,51,52,56}

-- This table specifies which type of grounded aircraft converts to which normal aircraft
grounded_to_air_types =
{
	["GroundedPolikarpovI16"] = "PolikarpovI16",
	["GroundedLaGG3"] = "LaGG3",
	["GroundedMiG3"] = "MiG3",
	["GroundedYakovlevYak1"] = "YakovlevYak1",
	["GroundedTupolevSB"] = "TupolevSB",
	["GroundedPetlyakovPe2"] = "PetlyakovPe2",
	["GroundedPetlyakovPe8"] = "PetlyakovPe8"
}

function LaunchAircraft(unit_id)
	local unit = world:GetUnit(unit_id)
	if (unit == nil) then		-- unit destroyed?
		return
	end

	local new_type = grounded_to_air_types[unit.type.name]
	if (new_type == nil) then		-- we don't know this unit type, ignore
		return
	end

	local hex = world:GetHex(unit.position)
	if (hex:GetUnit(1) ~= nil) then		-- air space above the unit is occupied, cannot launch
		return
	end

	local upgrade_action = world:MakeUpgradeAction(unit, new_type, "", unit.overstr)
	upgrade_action.cost = 0
	upgrade_action.slots = 0
	upgrade_action.xp_penalty = 0
	world:Exec(upgrade_action)
end

-- ** Effect(NewRoundAction) **
-- @FIXME: will be called _every_ round, even though only needs to fire 1x
function LaunchAllAircraft()	-- Launch aircraft starting from turn 3
	if (world.round < 3) then return end

	for _,id in ipairs(grounded_units) do
		LaunchAircraft(id)
	end
end
