-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 4 Objectives defined in scenario:
	-- 0 		Capture 5 victory hexes		(28;10)(26;11)(26;13)(27;13)(28;16)	-- Smolensk
	-- 1 opt	Capture 1 victory hexes		(38;6)		-- Yartsevo
	-- 2 opt	Capture 1 victory hexes		(40;20)		-- Glinka
	-- 3 opt	Unit must survive			unit ID 42	-- Wagner

-- 6 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	PlayerHero(NewRoundAction)	-- Wagner
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 1x	OnObjective2(CaptureFlagAction)		{if Objective2Condition()}
	-- 1x	EncounterAction(MoveAction)			{if EncounterCheck()}
	-- 1x	OnVictory(VictoryAction)	-- Wagner

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

---------------------
-- Player Hero(es) --
---------------------

wagner = {
	{unit_id=42, name=NSLOCTEXT("scenario_Smolensk1941","Stefan_Wagner","Stefan Wagner"), portrait="/Game/Gui/Common/Heroes/de_in_wagner.de_in_wagner", traits = {UnitTrait.Leadership, UnitTrait.NoSplit, UnitTrait.ArtySupport}}
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, wagner, true)	-- create silently, without usual Hero pop-up
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 4,
	eqs = {{"LaGG3",24},{"PetlyakovPe2",31},{"PetlyakovPe8",19}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Smolensk1941","difficult_choice2","Mein General, our salvage crews have come back with a progress report on all of the Soviet airfields we have overrun.  Although the overwhelming majority of enemy aircraft on the ground have been destroyed, there were a few that we actually captured intact.  I am told the designs are not exactly cutting edge, but perhaps you can find some use for them.\n\nYou have %d Commendation Points.\n\nWould you like to use 4 Commendation Points to acquire an assorted collection of captured Soviet fighter and bomber aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Smolensk1941","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Smolensk1941","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Smolensk1941","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Smolensk1941","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Smolensk1941","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Smolensk1941","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-----------------------------------------------------------
-- Objective 1: Raid Yartsevo before Smolensk is secured --
-----------------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Smolensk1941","earned_cp_format","Bonus Objective to Raid Yartsevo before Smolensk is secured completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------------------------------------------
-- Objective 2: Raid Glinka before Smolensk is secured --
---------------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 1
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Smolensk1941","earned_cp_format2","Bonus Objective to Raid Glinka before Smolensk is secured completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------------------------------------------
-- Objective 3: Wagner's Halftrack Survives the Battle --
---------------------------------------------------------

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** 1x Effect(VictoryAction) **
-- ** checked at scenario end **
function OnVictory()
	if (GetObjectiveStatus(0,3) == ObjectiveStatus.Fail) then return end

	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Smolensk1941","earned_cp_format3","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-----------------------------------
-- Proximity/Encounter detection --
-----------------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =
	{
		player = 0,
	}
	local filter2 =
	{
		player = p_RU,
		id = {41,43,44,45,46,47,48,49,50,51,52,53,54, 57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75}, -- aux units patrolling NW-NE & SW-SE of Smolensk
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_Smolensk1941","string_largesov1","<bi>Hauptmann Wagner: </>Mein General, our forces have confirmed my suspicions, they have made contact with large formations of Soviets roaming around Smolensk."))
	TutorialMessage(NSLOCTEXT("scenario_Smolensk1941","string_largesov2","<bi>Hauptmann Wagner: </>We may want to slow our advance to make sure our anti-tank weapons are in good supporting fire positions."), false)
end
