-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 3 Objectives defined in scenario:
	-- 0 @end	Capture 7 victory hexes		(17;6)(28;9)(14;11)(13;13)(19;13)(18;15)(34;18)(25;20)(8;21)(24;22)
	-- 1 opt	Capture 10 victory hexes	(17;6)(28;9)(14;11)(13;13)(19;13)(18;15)(34;18)(25;20)(8;21)(24;22)
	-- 2 opt	Unit must survive			unit ID 2		-- Wagner

-- 5 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	PlayerHero(NewRoundAction)	-- Wagner
	-- 1x	OnObjective1(CaptureFlagAction)		{if Objective1Condition()}
	-- 		OnNewRound(NewRoundAction)
	-- 1x	OnVictory(VictoryAction)	-- Wagner

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{25,1},{26,2},{26,3},{27,3},{28,3},{29,3},{30,3},{31,3},{32,4},{33,4}},
	{{41,3},{41,4},{40,5},{40,6},{40,7},{41,8},{41,9},{42,10},{42,11},{43,11},{44,11}},
	{{44,18},{45,18},{46,18},{43,19},{43,20},{42,21},{42,22},{41,23},{41,24},{41,25}}
}

--------------
-- Triggers --
--------------

---------------------
-- Player Hero(es) --
---------------------

wagner = {
	{unit_id=2, name=NSLOCTEXT("scenario_YelnyaOffensive","Stefan_Wagner","Stefan Wagner"), portrait="/Game/Gui/Common/Heroes/de_in_wagner.de_in_wagner", traits = {UnitTrait.Leadership, UnitTrait.NoSplit, UnitTrait.ArtySupport}}
}

-- ** 1x Effect(NewRoundAction) **
function PlayerHero()
	lib.CreateAndAssignHeroes(0, wagner, true)	-- create silently, without usual Hero pop-up
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 5,
	eqs = {{"Bf109Z", 26}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_YelnyaOffensive","difficult_choice2","Mein General, we have received an offer to replenish some of our prototype aircraft.  If you have been impressed with the performance of the Bf-109z, or finally wish to try it out, now is the opportunity to acquire more spare parts for them.\n\nYou have %d Commendation Points.\n\nWould you like to use 5 Commendation Points acquire a collection of prototype Bf109z aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_YelnyaOffensive","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_YelnyaOffensive","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_YelnyaOffensive","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_YelnyaOffensive","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Prototypes)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_YelnyaOffensive","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_YelnyaOffensive","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-----------------------------------------------------------------------
-- Objective 1: Hold all 10 Victory Hexes at the end of the Scenario --
-----------------------------------------------------------------------

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_YelnyaOffensive","earned_cp_format","Bonus Objective to Hold all 10 Victory Hexes at the end of the scenario completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-------------------------------------------------------------------
-- Objective 2: Hauptmann Wagner's Halftrack survives the battle --
-------------------------------------------------------------------

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** 1x Effect(VictoryAction) **
-- ** checked at scenario end **
function OnVictory()
	if (GetObjectiveStatus(0,2) == ObjectiveStatus.Fail) then return end

	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_YelnyaOffensive","earned_cp_format2","Bonus Objective for Wagner's Halftrack surviving completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {2,4,8,12,16,19}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"Regular","",1,900},{"Regular","",1,900},{"SUHWInf","SUTruck",2,900},{"T34-40","",1,900},{"BT7","",2,900},{"122mmM1938","SUTruck",2,900}},
	{{"Regular","",1,900},{"Regular","",1,900},{"SUHWInf","SUTruck",2,900},{"T34-40","",1,900},{"BT7","",2,900},{"BM13Katyusha","SUTruck",2,900}},
	{{"Regular","",2,900},{"Regular","",2,900},{"SUHWInf","SUTruck", 3, 900},{"SUCavalry","",1,900},{"SUMntInf","",1,900},{"45mmM1937","SUTruck",2,900},{"BA10","",1,900}},
	{{"KV1-40","",1,900},{"T28","",1,900},{"T50","",2,900},{"T34-40","",1,900},{"BT7","",2,900},{"T34-40","",2,900},{"37mmM1939AA","SUTruck",2,900},{"122mmM1938","SUTruck",2,900}},
	{{"Regular","",1,900},{"BA10","",1,900},{"KV2TNK","",1,900},{"BT7A-ATY","",2,900},{"BM13Katyusha","",1,900},{"GazAAMG-AA","",2,900},{"MiG3","",2,900}}
}

-- ** Effect(NewRoundAction) **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_RU, zones[math.random(#zones)], waves[math.random(#waves)])
end
