-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1
	-- 2 [AI]:	Germany - 1st Panzer
p_1div=2

-- 3 Objectives defined in scenario:
	-- 0 		Custom objective	CustomSuccess() | Fail()
	-- 1 opt	Capture all victory hexes
	-- 2 opt	Destroy 4 units		unit IDs 14,15,16,17	-- HQ units

-- 4 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(CaptureFlagAction)	{if Objective2Condition()}
	-- 1x	Turn3he111(NewRoundAction)		{if Turn3()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=17, traits={UnitTrait.Resilient}},		-- art "Burmistenko's HQ" NW of Pryluky, per scenario
	{unit_id=14, traits={UnitTrait.Overrun, UnitTrait.Avenger, UnitTrait.ArtySupport}},	-- aa/at "Kirponos's HQ" S of Pryluky, per scenario
	{unit_id=15, traits={UnitTrait.CripplingBlow}},	-- tank "Tupikov's HQ" E of Pryluky, per scenario
	{unit_id=16, traits={UnitTrait.Evasive, UnitTrait.TankKiller}},		-- cav "Budyonny's HQ" S of Romny, per scenario
	{unit_id=37, traits={UnitTrait.FastLearner, UnitTrait.NoSupply}} 	-- inf N of Lokhvitsa, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 5,
	eqs = {{"He111Z",23}}
}

-- ** Condition for Turn3he111() **
function Turn3()
	return world.round == 3
end

-- ** 1x Effect(NewRoundAction) {if Turn3()} **
function Turn3he111()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Lokhvitsa","difficult_choice2","Mein General, sorry for the interruption, but I forgot something.  You have a new offer of prototypes that has been awaiting approval.  It is another offer of special Heinkel strategic bombers.  What shall I do with the request?\n\nYou have %d Commendation Points.\n\nWould you like to use 5 Commendation Points acquire a collection of prototype He111z aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Lokhvitsa","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Lokhvitsa","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Lokhvitsa","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Lokhvitsa","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Prototypes)
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Lokhvitsa","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Lokhvitsa","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

-------------------------------------------------------------------------------------------------------------------------------------
-- Objective 0: Link up with 1st Panzer Group.  Linking up requires moving a ground unit within 2 hexes of a 1st Panzer Group unit --
-------------------------------------------------------------------------------------------------------------------------------------

-- *** Condition for Objective 0 success ***
function CustomSuccess()
	local filter1 =
	{
		player = 0,
		ground = true
	}
	local filter2 =
	{
		player = p_1div,
		id = {0,1,2,3,4,5,6,7,8,9,10,11,12,13,97},	-- unit IDs of 1st Panzer Group
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** Condition for Objective 0 failure **
-- ** checked at scenario end **
function CustomFail(action)
	return action:GetActionClass() == "TurnsLimitAction"
end

--------------------------------------------
-- Objective 1: Capture all victory hexes --
--------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Lokhvitsa","earned_cp_format","Bonus Objective to Capture all Victory Hexes completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

----------------------------------------------
-- Objective 2: Eliminate 4 Soviet HQ units --
----------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 3
	campaign.comm_points = lib.UpdateCommendationPoints(comm)

	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Lokhvitsa","earned_cp_format2","Bonus Objective to Eliminate 4 Soviet HQ units completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
