-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 3 Objectives defined in scenario:
	-- 0 		Capture all victory hexes
	-- 1 opt	Destroy 10 units	unit IDs 39,40,38,20,41,22,56,58,60,59,57,37,17	-- 50th Army
	-- 2 opt	Destroy 16 units	unit IDs 64,65,61,62,18,66,67,63,0,12,31,32,33,10,11,19,34,14,15,36	-- 13th Army

-- 4 Triggers defined in scenario:
	-- 1x	Wirn(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	OnObjective1(CaptureFlagAction)	{if Objective1Condition()}
	-- 1x	OnObjective2(CaptureFlagAction)	{if Objective2Condition()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=20, traits={UnitTrait.ExpertSupport, UnitTrait.Unyielding}},	-- at "50th Army" N of Bryansk, per scenario
	{unit_id=26, traits={UnitTrait.Vigilant, UnitTrait.TankKiller}},		-- inf eng E Bryansk, per scenario
	{unit_id=67, traits={UnitTrait.ATSupport, UnitTrait.PreciseOptics}},	-- tank "13th Army" NE Hill 39, per scenario
	{unit_id=83, traits={UnitTrait.LightningAttack, UnitTrait.AggressiveCounterattack}, modifiers={{type = Initiative, mod = 1},{type = Speed, mod = 20}}} 	-- tank "Mikhail Kalashnikov" W Pocep, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

---------------------
-- Player Hero(es) --
---------------------

-- ** 1x Effect(NewRoundAction) **
function Wirn()
	if (campaign.comm_points < 8) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Bryansk","difficult_choice","Herr General, I have a issue with some newly arrived personnel that needs resolving.  Somehow there was a serious mix-up, and instead of standard reinforcments, we have been sent a training cadre!  While I am trying to sort the problem by sending them back from the frontline, one of the officers-in-training has volunteered to stay on and serve.\n\nAccording to the documents I have seen, Officer Wirnsberger still has several months of training to complete, but he insists that he is ready to serve immediately.  Should I send him back, or try to incorporate him into your ranks?\n\nYou have %d Commendation Points.\n\nWould you like to exchange 8 Commendation Points for this unique sniper?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Bryansk","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Bryansk","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Bryansk","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Bryansk","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = -8
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		CreateUber()
	end
	local choice_made =
	{
		NSLOCTEXT("scenario_Bryansk","choice_made1","You decide to use some of your influence to promote this soldier.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Bryansk","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

wirn_hero = {
	{
		portrait= "/Game/Gui/Common/Heroes/de_in_wirnsberger.de_in_wirnsberger",
		name= NSLOCTEXT("scenario_Bryansk","Helmut_Wirnsberger","Helmut Wirnsberger"),
		traits= {UnitTrait.LowProfile,UnitTrait.IgnoresZOC},
		modifiers= {{type=Initiative,mod=3},{type=Speed,mod=10}},	--,{type=Spotting,mod=1}},
--		attack_modifiers= {{type=TargetType.Soft, mod=10}},
--		defense_modifiers= {{type=Ground,mod=10}},
		unit_classes= {UnitClass.Infantry}
	}
}

function CreateUber()
	lib.CreateAndAssignHeroes(0, wirn_hero)
end

---------------------------------------------------
-- Objective 1: Eliminate Soviet 50th Army Units --
---------------------------------------------------

-- ** Condition for OnObjective1() **
function Objective1Condition(action)
	return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective1Condition()} **
function OnObjective1(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Bryansk","earned_cp_format","Bonus Objective to Eliminate 50th Army Units completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end

---------------------------------------------------
-- Objective 2: Eliminate Soviet 13th Army Units --
---------------------------------------------------

-- ** Condition for OnObjective2() **
function Objective2Condition(action)
	return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end

-- ** 1x Effect(ObjectiveStatusAction) {if Objective2Condition()} **
function OnObjective2(action)
	local comm = 2
	campaign.comm_points = lib.UpdateCommendationPoints(comm)
	MessageBox(string.format(tostring(NSLOCTEXT("scenario_Bryansk","earned_cp_formatobj2","Bonus Objective to Eliminate 13th Army Units completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")), comm, campaign.comm_points))
end
