-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1
	-- 2 [AI]:	USSR - Siberian
p_Sib=2

-- 2 Objectives defined in scenario:
	-- 0 @end	Capture 5 victory hexes	(2;3)(26;6)(23;7)(28;8)(25;9)(24;11)(27;12)(21;17)(8;18)(14;26)(3;36)(24;39)(25;39)
	-- 1 opt	Capture 1 victory hex	(25;9)	-- Kremlin

-- 4 Triggers defined in scenario:
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	EncounterAction(MoveAction)			{if EncounterCheck()}
	-- 		OnNewRound(NewRoundAction)
	-- 		OnCaptureStoreHouse(CaptureFlagAction)

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

-------------------
-- Key Locations --
-------------------

cache = {
	loc = {{25,9}},	-- The Kremlin, per scenario
	eqs = {{"SU100Y",1}}
}

-- This table is initially empty, and will accumulate depots which we capture
-- Depots won't generate a bonus if we lose them and recapture for the second time
captured_depots = {}

-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
-- There can be any number of zones in this list, the game will pick a random one every time
zones = {
	{{27,1},{29,1},{30,2},{31,2},{32,2},{30,3},{31,3},{32,3},{31,4},{32,4},{33,4},{31,5},{32,5},{33,5}},
	{{34,10},{35,10},{34,11},{35,11},{35,12},{36,12},{35,13},{36,13},{35,14},{36,14},{34,15},{35,15},{36,15},{36,16},{37,16},{36,17}}
}

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id= 10, traits={UnitTrait.ArtySupport}},		-- aa/at E Tula, per scenario
	{unit_id= 49, traits={UnitTrait.NoRetreat, UnitTrait.NoSupply}},	-- inf "The Red Guard" in Kremlin, per scenario
	{unit_id= 55, traits={UnitTrait.DoubleSupport}},	-- art E Kremlin, per scenario
	{unit_id= 76, traits={UnitTrait.NoSurrender}},		-- at/aa in Moscow, per scenario
	{unit_id= 80, traits={UnitTrait.HitAndRun}},		-- rcn W of Istra, per scenario
	{unit_id=102, traits={UnitTrait.LightningAttack}},	-- tank NW of Tula, per scenario
	{unit_id=105, traits={UnitTrait.Provocator}} 		-- tank W of Podolsk, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

----------------------
-- Enemy unit waves --
----------------------

normal_wave_turns = {6,7,8,13,14,15,19,20}

-- Each unit set is a list of blocks in the following format: {"<Unit ID>","<Transport ID>", overstrength, experience}
-- If no organic transport is needed, its respective field should be empty string ("").
-- There can be any number of waves in this list, the game will pick a random one every time
waves = {
	{{"Regular","",1,900},{"Regular","",1,900},{"SUHWInf","SUTruck",2,900},{"T34-41","",1,900},{"BT7","",2,900},{"122mmM1938","SUTruck",2,900}},
	{{"Regular","",1,900},{"Regular","",1,900},{"SUHWInf","SUTruck",2,900},{"T34-41","",1,900},{"BT7","",2,900},{"BM13Katyusha","SUTruck",2,900}},
	{{"Regular","",2,900},{"Regular","",2,900},{"SUHWInf","SUTruck", 3, 900},{"SUCavalry","",1,900},{"SUMntInf","",1,900},{"45mmM1937","SUTruck",2,900},{"BA10","",1,900}},
	{{"KV1-41","",1,900},{"T28","",1,900},{"T50","",2,900},{"T34-41","",1,900},{"BT7","",2,900},{"T34-41","",2,900},{"37mmM1939AA","SUTruck",2,900},{"122mmM1938","SUTruck",2,900}},
	{{"Regular","",1,900},{"BA10","",1,900},{"KV2TNK","",1,900},{"BT7A-ATY","",2,900},{"BM13Katyusha","",1,900},{"GazAAMG-AA","",2,900},{"Il2Shturmovik","",0,900}}
}

-- ** Effect(NewRoundAction) **
-- Spawns enemy units
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if (world.round == 1) then math.randomseed(world.seed) end

	-- If we don't need to spawn any wave this turn then just finish
	if (not lib.IsItemInTable(normal_wave_turns, world.round)) then return end

	lib.SpawnWave(p_RU, zones[math.random(#zones)], waves[math.random(#waves)])
end

---------------------
-- Equipment cache --
---------------------

-- ** Effect(CaptureFlagAction) **
function OnCaptureStoreHouse(action)
	-- If this flag was not captured by Axis side, do nothing
	if (world:GetPlayer(action.new_owner).side_id ~= 0) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if (lib.IsItemInTable(captured_depots, action.flag)) then return end

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)

	if (lib.IsItemInTable(cache.loc, action.flag)) then
		lib.AddEquipments(0, cache.eqs, Captured)
		TutorialMessage(NSLOCTEXT("scenario_BattleofMoscow","string_sco1","<bi>Leutnant Gerhardt: </>Herr General, the news just came in, our forces have finally reached the Kremlin!"))
		TutorialMessage(NSLOCTEXT("scenario_BattleofMoscow","string_sco2","<bi>Leutnant Gerhardt: </>According to this report though, the Soviets have evacuated all of their ranking government officials.  Our troops were unable to locate Stalin or any of his inner circle."), false)
		TutorialMessage(NSLOCTEXT("scenario_BattleofMoscow","string_sco3","<bi>Leutnant Gerhardt: </>We have secured a wealth of files and documents though.  I just hope our men do not burn it all to stay warm before I can take a look at the haul.  There must be some valuable intelligence somewhere in there..."), false)
	end
end

--------------------------------
-- Siberian units encountered --
--------------------------------

-- ** Condition for EncounterAction() **
function EncounterCheck()
	local filter1 =
	{
		player = 0,
	}
	local filter2 =
	{
		player = p_Sib,
		id = {99,100,101,102,103,104, 79,105,106,107,108,109,110, 111,112,113,114,115,116},	-- Siberian units NW of Tula, SW and NE of Moscow, per scenario
		spotted_by = 0
	}
	return lib.ProximityCheck(filter1, filter2, 2)
end

-- ** 1x Effect(MoveAction) {if EncounterCheck()} **
function EncounterAction()
	TutorialMessage(NSLOCTEXT("scenario_BattleofMoscow","string_sib1","<bi>Leutnant Gerhardt: </>Herr General, I do not recognize the unit markings on those enemy vehicles.  There is nothing about them in any of our intelligence reports."))
	TutorialMessage(NSLOCTEXT("scenario_BattleofMoscow","string_sib2","<bi>Leutnant Gerhardt: </>I have a bad feeling that I may have been wrong about your briefing and this battle."), false)
end
