-- Players:
	-- 0 [H]:	Germany
	-- 1 [AI]:	USSR
p_RU=1

-- 2 Objectives defined in scenario:
	-- 0 @end	Capture 1 victory hex	(5;10)	-- Rzhev
	-- 1 opt	5 Units must survive	unit IDs 1,0,2,3,4	-- convoy trucks

-- 5 Triggers defined in scenario:
	-- 1x	OnStart(NewRoundAction)
	-- 1x	EnemyHero(NewRoundAction)
	-- 1x	MineHero(NewRoundAction)
	-- 1x	Turn14CheckKV(NewRoundAction)
	-- 1x	TigerTradeChoice(NewRoundAction)	{if Turn15Check()}

-- Use lib. prefix for utility and support functions:
lib = require "shared"	-- file shared.lua in campaign directory ../AO1941East

-- ** called automatically **
function OnMapStart()
	local value = campaign.comm_points or 0
	campaign.comm_points = lib.InitCommendationPoints(value)	-- UI: Commendation Points
end

--------------
-- Triggers --
--------------

------------------
-- Enemy heroes --
------------------

enemy_heroes = {
	-- @NOTE: name not provided (pick up from unit.name, if any)
	{unit_id=47, traits={UnitTrait.Vigilant, UnitTrait.IncMaxOverstrength}},		-- tank NE of Klin, per scenario
	{unit_id=48, traits={UnitTrait.DoubleAttack, UnitTrait.OverwhelmingAttack}},	-- inf NE of Klin, per scenario
	{unit_id=85, traits={UnitTrait.Avenger, UnitTrait.MachineGun}},	-- ftr SE of Klin, per scenario
	{unit_id=19, traits={UnitTrait.NoRetaliation}},	-- inf para S of Rzhev, per scenario
	{unit_id=25, traits={UnitTrait.SkilledRecon, UnitTrait.Ambusher, UnitTrait.Evasive}} 	-- tank NW Staritsa, per scenario
}

-- ** 1x Effect(NewRoundAction) **
-- Creates enemy Hero(es)
function EnemyHero()
	lib.CreateAndAssignHeroes(p_RU, enemy_heroes)
end

-------------------
-- Supply heroes --
-------------------

supply_heroes = {
	-- supply trucks:
	-- @TODO: , UnitTrait.NoSurrender, UnitTrait.Survivor, UnitTrait.LastStand
	{unit_id=0, name = NSLOCTEXT("scenario_Klin","Sips","Sips"), traits={UnitTrait.NoSplit}},
	{unit_id=1, name = NSLOCTEXT("scenario_Klin","Sjin","Sjin"), traits={UnitTrait.NoSplit}},
	{unit_id=2, name = NSLOCTEXT("scenario_Klin","Angory_Thomas","Angory Thomas"), traits={UnitTrait.NoSplit}},
	{unit_id=3, name = NSLOCTEXT("scenario_Klin","Simon","Simon"), traits={UnitTrait.NoSplit}},
	{unit_id=4, name = NSLOCTEXT("scenario_Klin","Dew","Dew"), traits={UnitTrait.NoSplit}}
}

-- ** 1x Effect(NewRoundAction) **
function MineHero()
	lib.CreateAndAssignHeroes(0, supply_heroes, true)	-- create silently, without usual Hero pop-up
end

----------------------
-- CP for equipment --
----------------------

trade = {
	cps = 5,
	eqs = {{"ZIS30",19},{"BM13Katyusha",18},{"MiG3",29},{"PetlyakovPe2",26}}
}

-- ** 1x Effect(NewRoundAction) **
function OnStart()
	if (campaign.comm_points < trade.cps) then return end

	local message = string.format(tostring(NSLOCTEXT("scenario_Klin","difficult_choice2","Herr General, as we prepare to withdraw, there is one extra task to consider.  There still are many captured Soviet vehicles and equipment we have not had a chance to return to working order.  Should we spend extra time and energy to retrieve what we can, or shall we just destroy them all so they cannot be reclaimed by the Soviets?\n\nYou have %d Commendation Points.\n\nWould you like to use 5 Commendation Points acquire a collection of captured Soviet vehicles and aircraft?")), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	choose_action.options = {
		{
			title  = NSLOCTEXT("scenario_Klin","option1","Authorize the exchange"),
			tooltip= NSLOCTEXT("scenario_Klin","option1_tooltip","")
		},
		{
			title  = NSLOCTEXT("scenario_Klin","option2","Decline the exchange"),
			tooltip= NSLOCTEXT("scenario_Klin","option2_tooltip","")
		}
	}
	world:Exec(choose_action)	-- "ProcessChoice" ==> ProcessChoice(player,choice)
end

function ProcessChoice(player, choice)
	if (choice == 1) then		-- The player chose option 1, which is "yes"
		local comm = 0 - trade.cps	-- make negative
		campaign.comm_points = lib.UpdateCommendationPoints(comm)
		lib.AddEquipments(player, trade.eqs, Captured)
	end

	local choice_made =
	{
		NSLOCTEXT("scenario_Klin","choice_made1","You choose to accept the offer.  You now have %d Commendation Points."),
		NSLOCTEXT("scenario_Klin","choice_made2","You choose to reject the offer.  You still have %d Commendation Points"),
	}
	MessageBox(string.format(tostring(choice_made[choice]), campaign.comm_points))
end

--------------------------------
-- Token for future prototype --
--------------------------------

uniquekv = false

-- ** 1x Effect(NewRoundAction) **
function Turn14CheckKV()	-- determine how many points of KV1-40 are captured at start of scenario (there are only KV-1/41 in this scenario)
	if (lib.CountEquipment(0, "KV1-40") >= 100) then
		uniquekv = true
	end
end

-- @TODO: .lib
function GetObjectiveStatus(side, objective)	-- support function: returns enum ObjectiveStatus (.Success|.Fail) of the given side's objective
	return world.sides[side+1].objectives[objective+1].status
end

-- ** Condition for TigerTradeChoice() **
function Turn15Check()
	return world.round == 15 and GetObjectiveStatus(0,1) ~= ObjectiveStatus.Fail	-- "Fail" = supply trucks still alive on Turn 15
end

-- ** Effect(NewRoundAction) {if Turn15Check()} **
function TigerTradeChoice()
	if (uniquekv == true) then
		local message = string.format(tostring(NSLOCTEXT("scenario_Klin","difficult_choiceTigerTrade","Herr General, the convoy survivors have sent their thanks for your rescue, but now the convoy leader has made an additional request.  He has asked if you would be willing to part with a large stockpile of captured Soviet tanks, to improve the haul the convoy will be able to send back to Kummersdorf for testing and analysis.  100 KV1 tank parts, to be exact.  While giving up some of our captured equipment brings no immediate benefit, it is very likely that sending so much equipment back to Germany would accelerate our own tank development projects.\n\nWill you agree to give up 100 KV1 tank parts in exchange for a potential reward in the future?")))
		local choose_action = world:MakeChooseAction(0, message, "ProcessChoice3")
		choose_action.options = {
			{
				title  = NSLOCTEXT("scenario_Klin","option1Messer","Authorize the exchange"),
				tooltip= NSLOCTEXT("scenario_Klin","option1_tooltip","")
			},
			{
				title  = NSLOCTEXT("scenario_Klin","option2Messer","Refuse the offer"),
				tooltip= NSLOCTEXT("scenario_Klin","option2_tooltip","")
			}
		}
		world:Exec(choose_action)	-- "ProcessChoice3" ==> ProcessChoice3(player,choice)
	end
end

function ProcessChoice3(player, choice)
	if (choice == 1) then
		TigerParts()
	end
	local choice_madeTigerTrade =
	{
		NSLOCTEXT("scenario_Klin","choice_made7","You agree hand over a haul of captured equipment.  You now have 100 less KV1 tank parts."),
		NSLOCTEXT("scenario_Klin","choice_made8","You decline the request."),
	}
	MessageBox(string.format(tostring(choice_madeTigerTrade[choice])))
end

function TigerParts()
	lib.AddEquipments(0, {{"Jagdtiger", 1}}, Prototypes)
	lib.AddEquipments(0, {{"KV1-40", -100}}, Captured)
end
